@@ -15,20 +15,25 @@
 
 import re
 
-from oslo.config import cfg
+from oslo_concurrency import lockutils
+from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_utils import excutils
+from oslo_utils import units
 
 from glance.common import exception
-from glance.openstack.common import excutils
-from glance.openstack.common import gettextutils
-from glance.openstack.common import log as logging
-from glance.openstack.common import units
+from glance.common import wsgi
+from glance import i18n
 
 LOG = logging.getLogger(__name__)
-_LE = gettextutils._LE
-_LI = gettextutils._LI
-_LW = gettextutils._LW
+_ = i18n._
+_LE = i18n._LE
+_LI = i18n._LI
+_LW = i18n._LW
 CONF = cfg.CONF
 
+_CACHED_THREAD_POOL = {}
+
 
 def size_checked_iter(response, image_meta, expected_size, image_iter,
                       notifier):
@@ -93,9 +98,11 @@ def image_send_notification(bytes_written, expected_size, image_meta, request,
 
 
 def get_remaining_quota(context, db_api, image_id=None):
-    """
-    This method is called to see if the user is allowed to store an image
-    of the given size in glance based on their quota and current usage.
+    """Method called to see if the user is allowed to store an image.
+
+    Checks if it is allowed based on the given size in glance based on their
+    quota and current usage.
+
     :param context:
     :param db_api:  The db_api in use for this configuration
     :param image_id: The image that will be replaced with this new data size
@@ -103,7 +110,7 @@ def get_remaining_quota(context, db_api, image_id=None):
              None means infinity
     """
 
-    #NOTE(jbresnah) in the future this value will come from a call to
+    # NOTE(jbresnah) in the future this value will come from a call to
     # keystone.
     users_quota = CONF.user_storage_quota
 
@@ -113,10 +120,11 @@ def get_remaining_quota(context, db_api, image_id=None):
     match = pattern.match(users_quota)
 
     if not match:
-        LOG.warn(_LW("Invalid value for option user_storage_quota: "
-                     "%(users_quota)s")
-                 % {'users_quota': users_quota})
-        return None
+        LOG.error(_LE("Invalid value for option user_storage_quota: "
+                      "%(users_quota)s")
+                  % {'users_quota': users_quota})
+        raise exception.InvalidOptionValue(option='user_storage_quota',
+                                           value=users_quota)
 
     quota_value, quota_unit = (match.groups())[0:2]
     # fall back to Bytes if user specified anything other than
@@ -126,7 +134,7 @@ def get_remaining_quota(context, db_api, image_id=None):
     users_quota = int(quota_value) * factor
 
     if users_quota <= 0:
-        return None
+        return
 
     usage = db_api.user_get_storage_usage(context,
                                           context.owner,
@@ -135,9 +143,11 @@ def get_remaining_quota(context, db_api, image_id=None):
 
 
 def check_quota(context, image_size, db_api, image_id=None):
-    """
-    This method is called to see if the user is allowed to store an image
-    of the given size in glance based on their quota and current usage.
+    """Method called to see if the user is allowed to store an image.
+
+    Checks if it is allowed based on the given size in glance based on their
+    quota and current usage.
+
     :param context:
     :param image_size:  The size of the image we hope to store
     :param db_api:  The db_api in use for this configuration
@@ -153,13 +163,13 @@ def check_quota(context, image_size, db_api, image_id=None):
     user = getattr(context, 'user', '<unknown>')
 
     if image_size is None:
-        #NOTE(jbresnah) When the image size is None it means that it is
+        # NOTE(jbresnah) When the image size is None it means that it is
         # not known.  In this case the only time we will raise an
         # exception is when there is no room left at all, thus we know
         # it will not fit
         if remaining <= 0:
-            LOG.info(_LI("User %(user)s attempted to upload an image of"
-                         " unknown size that will exceeed the quota."
+            LOG.warn(_LW("User %(user)s attempted to upload an image of"
+                         " unknown size that will exceed the quota."
                          " %(remaining)d bytes remaining.")
                      % {'user': user, 'remaining': remaining})
             raise exception.StorageQuotaFull(image_size=image_size,
@@ -167,11 +177,44 @@ def check_quota(context, image_size, db_api, image_id=None):
         return
 
     if image_size > remaining:
-        LOG.info(_LI("User %(user)s attempted to upload an image of size"
-                     " %(size)d that will exceeed the quota. %(remaining)d"
+        LOG.warn(_LW("User %(user)s attempted to upload an image of size"
+                     " %(size)d that will exceed the quota. %(remaining)d"
                      " bytes remaining.")
                  % {'user': user, 'size': image_size, 'remaining': remaining})
         raise exception.StorageQuotaFull(image_size=image_size,
                                          remaining=remaining)
 
     return remaining
+
+
+def memoize(lock_name):
+    def memoizer_wrapper(func):
+        @lockutils.synchronized(lock_name)
+        def memoizer(lock_name):
+            if lock_name not in _CACHED_THREAD_POOL:
+                _CACHED_THREAD_POOL[lock_name] = func()
+
+            return _CACHED_THREAD_POOL[lock_name]
+
+        return memoizer(lock_name)
+
+    return memoizer_wrapper
+
+
+def get_thread_pool(lock_name, size=1024):
+    """Initializes eventlet thread pool.
+
+    If thread pool is present in cache, then returns it from cache
+    else create new pool, stores it in cache and return newly created
+    pool.
+
+    @param lock_name:  Name of the lock.
+    @param size: Size of eventlet pool.
+
+    @return: eventlet pool
+    """
+    @memoize(lock_name)
+    def _get_thread_pool():
+        return wsgi.get_asynchronous_eventlet_pool(size=size)
+
+    return _get_thread_pool
