@@ -12,26 +12,26 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
-from oslo.config import cfg
-import webob.exc
-
 import glance_store as store_api
+from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_utils import excutils
+import webob.exc
 
 from glance.common import exception
 from glance.common import store_utils
 from glance.common import utils
 import glance.db
-from glance.openstack.common import excutils
-from glance.openstack.common import gettextutils
-import glance.openstack.common.log as logging
+from glance import i18n
 import glance.registry.client.v1.api as registry
 
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
-_LE = gettextutils._LE
-_LI = gettextutils._LI
+_ = i18n._
+_LE = i18n._LE
+_LI = i18n._LI
+_LW = i18n._LW
 
 
 def initiate_deletion(req, location_data, id):
@@ -205,8 +205,9 @@ def upload_data_to_store(req, image_meta, image_data, store, notifier):
                                  content_type='text/plain')
 
     except exception.Duplicate as e:
-        msg = u"Attempt to upload duplicate image: %s" % e
-        LOG.debug(msg)
+        msg = (_("Attempt to upload duplicate image: %s") %
+               utils.exception_to_str(e))
+        LOG.warn(msg)
         # NOTE(dosaboy): do not delete the image since it is likely that this
         # conflict is a result of another concurrent upload that will be
         # successful.
@@ -216,8 +217,9 @@ def upload_data_to_store(req, image_meta, image_data, store, notifier):
                                      content_type="text/plain")
 
     except exception.Forbidden as e:
-        msg = u"Forbidden upload attempt: %s" % e
-        LOG.debug(msg)
+        msg = (_("Forbidden upload attempt: %s") %
+               utils.exception_to_str(e))
+        LOG.warn(msg)
         safe_kill(req, image_id, 'saving')
         notifier.error('image.upload', msg)
         raise webob.exc.HTTPForbidden(explanation=msg,
@@ -225,7 +227,8 @@ def upload_data_to_store(req, image_meta, image_data, store, notifier):
                                       content_type="text/plain")
 
     except store_api.StorageFull as e:
-        msg = _("Image storage media is full: %s") % utils.exception_to_str(e)
+        msg = (_("Image storage media is full: %s") %
+               utils.exception_to_str(e))
         LOG.error(msg)
         safe_kill(req, image_id, 'saving')
         notifier.error('image.upload', msg)
@@ -246,7 +249,7 @@ def upload_data_to_store(req, image_meta, image_data, store, notifier):
     except exception.ImageSizeLimitExceeded as e:
         msg = (_("Denying attempt to upload image larger than %d bytes.")
                % CONF.image_size_cap)
-        LOG.info(msg)
+        LOG.warn(msg)
         safe_kill(req, image_id, 'saving')
         notifier.error('image.upload', msg)
         raise webob.exc.HTTPRequestEntityTooLarge(explanation=msg,
@@ -254,9 +257,9 @@ def upload_data_to_store(req, image_meta, image_data, store, notifier):
                                                   content_type='text/plain')
 
     except exception.StorageQuotaFull as e:
-        msg = (_("Denying attempt to upload image because it exceeds the ."
+        msg = (_("Denying attempt to upload image because it exceeds the "
                  "quota: %s") % utils.exception_to_str(e))
-        LOG.info(msg)
+        LOG.warn(msg)
         safe_kill(req, image_id, 'saving')
         notifier.error('image.upload', msg)
         raise webob.exc.HTTPRequestEntityTooLarge(explanation=msg,
@@ -264,7 +267,7 @@ def upload_data_to_store(req, image_meta, image_data, store, notifier):
                                                   content_type='text/plain')
 
     except webob.exc.HTTPError:
-        #NOTE(bcwaldon): Ideally, we would just call 'raise' here,
+        # NOTE(bcwaldon): Ideally, we would just call 'raise' here,
         # but something in the above function calls is affecting the
         # exception context and we must explicitly re-raise the
         # caught exception.
@@ -275,8 +278,8 @@ def upload_data_to_store(req, image_meta, image_data, store, notifier):
             safe_kill(req, image_id, 'saving')
 
     except (ValueError, IOError) as e:
-        msg = "Client disconnected before sending all data to backend"
-        LOG.debug(msg)
+        msg = _("Client disconnected before sending all data to backend")
+        LOG.warn(msg)
         safe_kill(req, image_id, 'saving')
         raise webob.exc.HTTPBadRequest(explanation=msg,
                                        content_type="text/plain",
