@@ -12,10 +12,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
-import webob.exc
-
 import glance_store
+from oslo_log import log as logging
+from oslo_utils import excutils
+import webob.exc
 
 import glance.api.policy
 from glance.common import exception
@@ -23,14 +23,13 @@ from glance.common import utils
 from glance.common import wsgi
 import glance.db
 import glance.gateway
+from glance import i18n
 import glance.notifier
-from glance.openstack.common import excutils
-from glance.openstack.common import gettextutils
-import glance.openstack.common.log as logging
 
 
 LOG = logging.getLogger(__name__)
-_LE = gettextutils._LE
+_ = i18n._
+_LE = i18n._LE
 
 
 class ImageDataController(object):
@@ -74,12 +73,11 @@ class ImageDataController(object):
                 image_repo.save(image)
                 image.set_data(data, size)
                 image_repo.save(image, from_state='saving')
-            except (exception.NotFound, exception.Conflict) as e:
-                msg = (_("Image %(id)s could not be found after upload."
-                         "The image may have been deleted during the upload: "
-                         "%(error)s Cleaning up the chunks uploaded") %
-                       {'id': image_id,
-                        'error': utils.exception_to_str(e)})
+            except (exception.NotFound, exception.Conflict):
+                msg = (_("Image %s could not be found after upload. "
+                         "The image may have been deleted during the "
+                         "upload, cleaning up the chunks uploaded.") %
+                       image_id)
                 LOG.warn(msg)
                 # NOTE(sridevi): Cleaning up the uploaded chunks.
                 try:
@@ -107,8 +105,8 @@ class ImageDataController(object):
             LOG.debug("Cannot save data for image %(id)s: %(e)s",
                       {'id': image_id, 'e': utils.exception_to_str(e)})
             self._restore(image_repo, image)
-            raise webob.exc.HTTPBadRequest(explanation=
-                                           utils.exception_to_str(e))
+            raise webob.exc.HTTPBadRequest(
+                explanation=utils.exception_to_str(e))
 
         except glance_store.StoreAddDisabled:
             msg = _("Error in store configuration. Adding images to store "
@@ -120,7 +118,7 @@ class ImageDataController(object):
 
         except exception.InvalidImageStatusTransition as e:
             msg = utils.exception_to_str(e)
-            LOG.debug(msg)
+            LOG.exception(msg)
             raise webob.exc.HTTPConflict(explanation=e.msg, request=req)
 
         except exception.Forbidden as e:
@@ -183,8 +181,10 @@ class ImageDataController(object):
         image_repo = self.gateway.get_repo(req.context)
         try:
             image = image_repo.get(image_id)
-            if not image.locations:
-                raise exception.ImageDataNotFound()
+            if image.status == 'deactivated':
+                msg = _('The requested image has been deactivated. '
+                        'Image data download is forbidden.')
+                raise exception.Forbidden(message=msg)
         except exception.ImageDataNotFound as e:
             raise webob.exc.HTTPNoContent(explanation=e.msg)
         except exception.NotFound as e:
@@ -231,15 +231,20 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
             response.app_iter = iter(image.get_data(offset=offset,
                                                     chunk_size=chunk_size))
         except glance_store.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=e.msg)
+            raise webob.exc.HTTPNoContent(explanation=e.msg)
+        except glance_store.RemoteServiceUnavailable as e:
+            raise webob.exc.HTTPServiceUnavailable(explanation=e.msg)
+        except (glance_store.StoreGetNotSupported,
+                glance_store.StoreRandomGetNotSupported) as e:
+            raise webob.exc.HTTPBadRequest(explanation=e.msg)
         except exception.Forbidden as e:
             raise webob.exc.HTTPForbidden(explanation=e.msg)
-        #NOTE(saschpe): "response.app_iter = ..." currently resets Content-MD5
+        # NOTE(saschpe): "response.app_iter = ..." currently resets Content-MD5
         # (https://github.com/Pylons/webob/issues/86), so it should be set
         # afterwards for the time being.
         if image.checksum:
             response.headers['Content-MD5'] = image.checksum
-        #NOTE(markwash): "response.app_iter = ..." also erroneously resets the
+        # NOTE(markwash): "response.app_iter = ..." also erroneously resets the
         # content-length
         response.headers['Content-Length'] = str(image.size)
 
