@@ -12,10 +12,9 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
-import webob.exc
-
 import glance_store
+from oslo_log import log as logging
+import webob.exc
 
 from glance.api import policy
 from glance.common import exception
@@ -23,9 +22,14 @@ from glance.common import utils
 from glance.common import wsgi
 import glance.db
 import glance.gateway
+from glance import i18n
 import glance.notifier
 
 
+LOG = logging.getLogger(__name__)
+_ = i18n._
+
+
 class Controller(object):
     def __init__(self, db_api=None, policy_enforcer=None, notifier=None,
                  store_api=None):
@@ -43,12 +47,23 @@ class Controller(object):
             image = image_repo.get(image_id)
             image.tags.add(tag_value)
             image_repo.save(image)
-        except exception.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=e.msg)
-        except exception.Forbidden as e:
-            raise webob.exc.HTTPForbidden(explanation=e.msg)
+        except exception.NotFound:
+            msg = _("Image %s not found.") % image_id
+            LOG.warning(msg)
+            raise webob.exc.HTTPNotFound(explanation=msg)
+        except exception.Forbidden:
+            msg = _("Not allowed to update tags for image %s.") % image_id
+            LOG.warning(msg)
+            raise webob.exc.HTTPForbidden(explanation=msg)
+        except exception.Invalid as e:
+            msg = _("Could not update image: %s") % utils.exception_to_str(e)
+            LOG.warning(msg)
+            raise webob.exc.HTTPBadRequest(explanation=msg)
         except exception.ImageTagLimitExceeded as e:
-            raise webob.exc.HTTPRequestEntityTooLarge(explanation=e.msg)
+            msg = (_("Image tag limit exceeded for image %(id)s: %(e)s:")
+                   % {"id": image_id, "e": utils.exception_to_str(e)})
+            LOG.warning(msg)
+            raise webob.exc.HTTPRequestEntityTooLarge(explanation=msg)
 
     @utils.mutating
     def delete(self, req, image_id, tag_value):
@@ -59,10 +74,14 @@ class Controller(object):
                 raise webob.exc.HTTPNotFound()
             image.tags.remove(tag_value)
             image_repo.save(image)
-        except exception.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=e.msg)
-        except exception.Forbidden as e:
-            raise webob.exc.HTTPForbidden(explanation=e.msg)
+        except exception.NotFound:
+            msg = _("Image %s not found.") % image_id
+            LOG.warning(msg)
+            raise webob.exc.HTTPNotFound(explanation=msg)
+        except exception.Forbidden:
+            msg = _("Not allowed to delete tags for image %s.") % image_id
+            LOG.warning(msg)
+            raise webob.exc.HTTPForbidden(explanation=msg)
 
 
 class ResponseSerializer(wsgi.JSONResponseSerializer):
