@@ -13,12 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo.config import cfg
+from oslo.serialization import jsonutils
+from oslo_config import cfg
+from oslo_log import log as logging
 import six
 import six.moves.urllib.parse as urlparse
 import webob.exc
-from wsme.rest.json import fromjson
-from wsme.rest.json import tojson
+from wsme.rest import json
 
 from glance.api import policy
 from glance.api.v2.model.metadef_namespace import Namespace
@@ -26,6 +27,7 @@ from glance.api.v2.model.metadef_namespace import Namespaces
 from glance.api.v2.model.metadef_object import MetadefObject
 from glance.api.v2.model.metadef_property_type import PropertyType
 from glance.api.v2.model.metadef_resource_type import ResourceTypeAssociation
+from glance.api.v2.model.metadef_tag import MetadefTag
 from glance.common import exception
 from glance.common import utils
 from glance.common import wsgi
@@ -34,11 +36,10 @@ import glance.db
 import glance.gateway
 from glance import i18n
 import glance.notifier
-from glance.openstack.common import jsonutils as json
-import glance.openstack.common.log as logging
 import glance.schema
 
 LOG = logging.getLogger(__name__)
+_ = i18n._
 _LE = i18n._LE
 _LW = i18n._LW
 _LI = i18n._LI
@@ -47,13 +48,16 @@ CONF = cfg.CONF
 
 
 class NamespaceController(object):
-    def __init__(self, db_api=None, policy_enforcer=None):
+    def __init__(self, db_api=None, policy_enforcer=None, notifier=None):
         self.db_api = db_api or glance.db.get_api()
         self.policy = policy_enforcer or policy.Enforcer()
+        self.notifier = notifier or glance.notifier.Notifier()
         self.gateway = glance.gateway.Gateway(db_api=self.db_api,
+                                              notifier=self.notifier,
                                               policy_enforcer=self.policy)
         self.ns_schema_link = '/v2/schemas/metadefs/namespace'
         self.obj_schema_link = '/v2/schemas/metadefs/object'
+        self.tag_schema_link = '/v2/schemas/metadefs/tag'
 
     def index(self, req, marker=None, limit=None, sort_key='created_at',
               sort_dir='desc', filters=None):
@@ -112,10 +116,11 @@ class NamespaceController(object):
             namespace_created = True
 
             # Create Resource Types
-            rs_factory = (
-                self.gateway.get_metadef_resource_type_factory(req.context))
-            rs_repo = self.gateway.get_metadef_resource_type_repo(req.context)
             if namespace.resource_type_associations:
+                rs_factory = (self.gateway.get_metadef_resource_type_factory(
+                    req.context))
+                rs_repo = self.gateway.get_metadef_resource_type_repo(
+                    req.context)
                 for resource_type in namespace.resource_type_associations:
                     new_resource = rs_factory.new_resource_type(
                         namespace=namespace.namespace,
@@ -123,22 +128,34 @@ class NamespaceController(object):
                     rs_repo.add(new_resource)
 
             # Create Objects
-            object_factory = self.gateway.get_metadef_object_factory(
-                req.context)
-            object_repo = self.gateway.get_metadef_object_repo(req.context)
-
             if namespace.objects:
+                object_factory = self.gateway.get_metadef_object_factory(
+                    req.context)
+                object_repo = self.gateway.get_metadef_object_repo(
+                    req.context)
                 for metadata_object in namespace.objects:
                     new_meta_object = object_factory.new_object(
                         namespace=namespace.namespace,
                         **metadata_object.to_dict())
                     object_repo.add(new_meta_object)
 
+            # Create Tags
+            if namespace.tags:
+                tag_factory = self.gateway.get_metadef_tag_factory(
+                    req.context)
+                tag_repo = self.gateway.get_metadef_tag_repo(req.context)
+                for metadata_tag in namespace.tags:
+                    new_meta_tag = tag_factory.new_tag(
+                        namespace=namespace.namespace,
+                        **metadata_tag.to_dict())
+                    tag_repo.add(new_meta_tag)
+
             # Create Namespace Properties
-            prop_factory = (
-                self.gateway.get_metadef_property_factory(req.context))
-            prop_repo = self.gateway.get_metadef_property_repo(req.context)
             if namespace.properties:
+                prop_factory = (self.gateway.get_metadef_property_factory(
+                    req.context))
+                prop_repo = self.gateway.get_metadef_property_repo(
+                    req.context)
                 for (name, value) in namespace.properties.items():
                     new_property_type = (
                         prop_factory.new_namespace_property(
@@ -165,6 +182,7 @@ class NamespaceController(object):
         new_namespace.objects = namespace.objects
         new_namespace.resource_type_associations = (
             namespace.resource_type_associations)
+        new_namespace.tags = namespace.tags
         return Namespace.to_wsme_model(new_namespace,
                                        get_namespace_href(new_namespace),
                                        self.ns_schema_link)
@@ -172,7 +190,7 @@ class NamespaceController(object):
     def _to_property_dict(self, name, value):
         # Convert the model PropertyTypes dict to a JSON string
         db_property_type_dict = dict()
-        db_property_type_dict['schema'] = tojson(PropertyType, value)
+        db_property_type_dict['schema'] = json.tojson(PropertyType, value)
         db_property_type_dict['name'] = name
         return db_property_type_dict
 
@@ -232,6 +250,14 @@ class NamespaceController(object):
                 namespace_detail = self._prefix_property_name(
                     namespace_detail, filters['resource_type'])
 
+            # Get tags
+            tag_repo = self.gateway.get_metadef_tag_repo(req.context)
+            db_metatag_list = tag_repo.list(filters=ns_filters)
+            tag_list = [MetadefTag(**{'name': db_metatag.name})
+                        for db_metatag in db_metatag_list]
+            if tag_list:
+                namespace_detail.tags = tag_list
+
         except exception.Forbidden as e:
             raise webob.exc.HTTPForbidden(explanation=e.msg)
         except exception.NotFound as e:
@@ -245,6 +271,7 @@ class NamespaceController(object):
         namespace_repo = self.gateway.get_metadef_namespace_repo(req.context)
         try:
             ns_obj = namespace_repo.get(namespace)
+            ns_obj._old_namespace = ns_obj.namespace
             ns_obj.namespace = wsme_utils._get_value(user_ns.namespace)
             ns_obj.display_name = wsme_utils._get_value(user_ns.display_name)
             ns_obj.description = wsme_utils._get_value(user_ns.description)
@@ -299,6 +326,20 @@ class NamespaceController(object):
             LOG.error(utils.exception_to_str(e))
             raise webob.exc.HTTPInternalServerError()
 
+    def delete_tags(self, req, namespace):
+        ns_repo = self.gateway.get_metadef_namespace_repo(req.context)
+        try:
+            namespace_obj = ns_repo.get(namespace)
+            namespace_obj.delete()
+            ns_repo.remove_tags(namespace_obj)
+        except exception.Forbidden as e:
+            raise webob.exc.HTTPForbidden(explanation=e.msg)
+        except exception.NotFound as e:
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
+        except Exception as e:
+            LOG.error(utils.exception_to_str(e))
+            raise webob.exc.HTTPInternalServerError()
+
     def delete_properties(self, req, namespace):
         ns_repo = self.gateway.get_metadef_namespace_repo(req.context)
         try:
@@ -430,7 +471,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
             self.schema.validate(body)
         except exception.InvalidObject as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
-        namespace = fromjson(Namespace, body)
+        namespace = json.fromjson(Namespace, body)
         return dict(namespace=namespace)
 
     def update(self, request):
@@ -440,7 +481,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
             self.schema.validate(body)
         except exception.InvalidObject as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
-        namespace = fromjson(Namespace, body)
+        namespace = json.fromjson(Namespace, body)
         return dict(user_ns=namespace)
 
 
@@ -450,12 +491,12 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
         self.schema = schema
 
     def create(self, response, namespace):
-        ns_json = tojson(Namespace, namespace)
+        ns_json = json.tojson(Namespace, namespace)
         response = self.__render(ns_json, response, 201)
         response.location = get_namespace_href(namespace)
 
     def show(self, response, namespace):
-        ns_json = tojson(Namespace, namespace)
+        ns_json = json.tojson(Namespace, namespace)
         response = self.__render(ns_json, response)
 
     def index(self, response, result):
@@ -471,11 +512,11 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
             next_query = urlparse.urlencode(params)
             result.next = '/v2/metadefs/namespaces?%s' % next_query
 
-        ns_json = tojson(Namespaces, result)
+        ns_json = json.tojson(Namespaces, result)
         response = self.__render(ns_json, response)
 
     def update(self, response, namespace):
-        ns_json = tojson(Namespace, namespace)
+        ns_json = json.tojson(Namespace, namespace)
         response = self.__render(ns_json, response, 200)
 
     def delete(self, response, result):
@@ -488,7 +529,7 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
         response.status_int = 204
 
     def __render(self, json_data, response, response_status=None):
-        body = json.dumps(json_data, ensure_ascii=False)
+        body = jsonutils.dumps(json_data, ensure_ascii=False)
         response.unicode_body = six.text_type(body)
         response.content_type = 'application/json'
         if response_status:
@@ -533,6 +574,12 @@ def get_schema_definitions():
                     "description": {
                         "type": "string"
                     },
+                    "operators": {
+                        "type": "array",
+                        "items": {
+                            "type": "string"
+                        }
+                    },
                     "type": {
                         "type": "string",
                         "enum": [
@@ -700,7 +747,18 @@ def _get_base_properties():
                     },
                 }
             }
-        }
+        },
+        "tags": {
+            "type": "array",
+            "items": {
+                "type": "object",
+                "properties": {
+                    "name": {
+                        "type": "string"
+                    }
+                }
+            }
+        },
     }
 
 
@@ -733,6 +791,12 @@ def get_object_href(namespace_name, metadef_object):
         return base_href
 
 
+def get_tag_href(namespace_name, metadef_tag):
+        base_href = ('/v2/metadefs/namespaces/%s/tags/%s' %
+                     (namespace_name, metadef_tag.name))
+        return base_href
+
+
 def create_resource():
     """Namespaces resource factory method"""
     schema = get_schema()
