@@ -13,11 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo.config import cfg
+from oslo.serialization import jsonutils
+from oslo_config import cfg
+from oslo_log import log as logging
 import six
 import webob.exc
-from wsme.rest.json import fromjson
-from wsme.rest.json import tojson
+from wsme.rest import json
 
 from glance.api import policy
 from glance.api.v2 import metadef_namespaces as namespaces
@@ -30,11 +31,10 @@ from glance.common import wsme_utils
 import glance.db
 from glance import i18n
 import glance.notifier
-from glance.openstack.common import jsonutils as json
-import glance.openstack.common.log as logging
 import glance.schema
 
 LOG = logging.getLogger(__name__)
+_ = i18n._
 _LE = i18n._LE
 _LI = i18n._LI
 
@@ -42,10 +42,12 @@ CONF = cfg.CONF
 
 
 class MetadefObjectsController(object):
-    def __init__(self, db_api=None, policy_enforcer=None):
+    def __init__(self, db_api=None, policy_enforcer=None, notifier=None):
         self.db_api = db_api or glance.db.get_api()
         self.policy = policy_enforcer or policy.Enforcer()
+        self.notifier = notifier or glance.notifier.Notifier()
         self.gateway = glance.gateway.Gateway(db_api=self.db_api,
+                                              notifier=self.notifier,
                                               policy_enforcer=self.policy)
         self.obj_schema_link = '/v2/schemas/metadefs/object'
 
@@ -117,6 +119,7 @@ class MetadefObjectsController(object):
         meta_repo = self.gateway.get_metadef_object_repo(req.context)
         try:
             metadef_object = meta_repo.get(namespace, object_name)
+            metadef_object._old_name = metadef_object.name
             metadef_object.name = wsme_utils._get_value(
                 metadata_object.name)
             metadef_object.description = wsme_utils._get_value(
@@ -233,7 +236,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
             self.schema.validate(body)
         except exception.InvalidObject as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
-        metadata_object = fromjson(MetadefObject, body)
+        metadata_object = json.fromjson(MetadefObject, body)
         return dict(metadata_object=metadata_object)
 
     def update(self, request):
@@ -243,7 +246,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
             self.schema.validate(body)
         except exception.InvalidObject as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
-        metadata_object = fromjson(MetadefObject, body)
+        metadata_object = json.fromjson(MetadefObject, body)
         return dict(metadata_object=metadata_object)
 
     def index(self, request):
@@ -300,8 +303,8 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
         self.show(response, metadata_object)
 
     def show(self, response, metadata_object):
-        metadata_object_json = tojson(MetadefObject, metadata_object)
-        body = json.dumps(metadata_object_json, ensure_ascii=False)
+        metadata_object_json = json.tojson(MetadefObject, metadata_object)
+        body = jsonutils.dumps(metadata_object_json, ensure_ascii=False)
         response.unicode_body = six.text_type(body)
         response.content_type = 'application/json'
 
@@ -311,8 +314,8 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
 
     def index(self, response, result):
         result.schema = "v2/schemas/metadefs/objects"
-        metadata_objects_json = tojson(MetadefObjects, result)
-        body = json.dumps(metadata_objects_json, ensure_ascii=False)
+        metadata_objects_json = json.tojson(MetadefObjects, result)
+        body = jsonutils.dumps(metadata_objects_json, ensure_ascii=False)
         response.unicode_body = six.text_type(body)
         response.content_type = 'application/json'
 
