@@ -15,12 +15,15 @@
 # under the License.
 
 import copy
-import webob.exc
 
 import glance_store
-from oslo.config import cfg
+import oslo.serialization.jsonutils as json
+from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_utils import timeutils
 import six
 import six.moves.urllib.parse as urlparse
+import webob.exc
 
 from glance.api import policy
 from glance.common import exception
@@ -28,15 +31,13 @@ from glance.common import utils
 from glance.common import wsgi
 import glance.db
 import glance.gateway
+from glance import i18n
 import glance.notifier
-from glance.openstack.common import gettextutils
-import glance.openstack.common.jsonutils as json
-import glance.openstack.common.log as logging
-from glance.openstack.common import timeutils
 import glance.schema
 
 LOG = logging.getLogger(__name__)
-_LI = gettextutils._LI
+_ = i18n._
+_LW = i18n._LW
 
 CONF = cfg.CONF
 CONF.import_opt('task_time_to_live', 'glance.common.config', group='task')
@@ -68,9 +69,9 @@ class TasksController(object):
             task_executor = executor_factory.new_task_executor(req.context)
             new_task.run(task_executor)
         except exception.Forbidden as e:
-            msg = (_LI("Forbidden to create task. Reason: %(reason)s")
+            msg = (_LW("Forbidden to create task. Reason: %(reason)s")
                    % {'reason': utils.exception_to_str(e)})
-            LOG.info(msg)
+            LOG.warn(msg)
             raise webob.exc.HTTPForbidden(explanation=e.msg)
         return new_task
 
@@ -93,10 +94,10 @@ class TasksController(object):
                 result['next_marker'] = tasks[-1].task_id
         except (exception.NotFound, exception.InvalidSortKey,
                 exception.InvalidFilterRangeValue) as e:
-            LOG.info(utils.exception_to_str(e))
+            LOG.warn(utils.exception_to_str(e))
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
         except exception.Forbidden as e:
-            LOG.info(utils.exception_to_str(e))
+            LOG.warn(utils.exception_to_str(e))
             raise webob.exc.HTTPForbidden(explanation=e.msg)
         result['tasks'] = tasks
         return result
@@ -106,15 +107,15 @@ class TasksController(object):
             task_repo = self.gateway.get_task_repo(req.context)
             task = task_repo.get(task_id)
         except exception.NotFound as e:
-            msg = (_LI("Failed to find task %(task_id)s. Reason: %(reason)s") %
+            msg = (_LW("Failed to find task %(task_id)s. Reason: %(reason)s") %
                    {'task_id': task_id, 'reason': utils.exception_to_str(e)})
-            LOG.info(msg)
+            LOG.warn(msg)
             raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Forbidden as e:
-            msg = (_LI("Forbidden to get task %(task_id)s. Reason:"
+            msg = (_LW("Forbidden to get task %(task_id)s. Reason:"
                        " %(reason)s") %
                    {'task_id': task_id, 'reason': utils.exception_to_str(e)})
-            LOG.info(msg)
+            LOG.warn(msg)
             raise webob.exc.HTTPForbidden(explanation=e.msg)
         return task
 
@@ -133,7 +134,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
     def _get_request_body(self, request):
         output = super(RequestDeserializer, self).default(request)
         if 'body' not in output:
-            msg = _('Body expected in request')
+            msg = _('Body expected in request.')
             raise webob.exc.HTTPBadRequest(explanation=msg)
         return output['body']
 
@@ -228,8 +229,8 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
     def __init__(self, task_schema=None, partial_task_schema=None):
         super(ResponseSerializer, self).__init__()
         self.task_schema = task_schema or get_task_schema()
-        self.partial_task_schema = partial_task_schema \
-            or _get_partial_task_schema()
+        self.partial_task_schema = (partial_task_schema
+                                    or _get_partial_task_schema())
 
     def _inject_location_header(self, response, task):
         location = self._get_task_location(task)
@@ -329,11 +330,11 @@ _TASK_SCHEMA = {
     },
     "input": {
         "description": _("The parameters required by task, JSON blob"),
-        "type": "object"
+        "type": ["null", "object"],
     },
     "result": {
         "description": _("The result of current task, JSON blob"),
-        "type": "object",
+        "type": ["null", "object"],
     },
     "owner": {
         "description": _("An identifier for the owner of this task"),
@@ -347,7 +348,7 @@ _TASK_SCHEMA = {
     "expires_at": {
         "description": _("Datetime when this resource would be"
                          " subject to removal"),
-        "type": "string"
+        "type": ["null", "string"]
     },
     "created_at": {
         "description": _("Datetime when this resource was created"),
