@@ -15,14 +15,26 @@
 
 import httplib
 
-from oslo.config import cfg
+from oslo.serialization import jsonutils
+from oslo_config import cfg
 import webob.dec
 
 from glance.common import wsgi
-from glance.openstack.common import jsonutils
+from glance import i18n
 
+_ = i18n._
+
+versions_opts = [
+    cfg.StrOpt('public_endpoint', default=None,
+               help=_('Public url to use for versions endpoint. The default '
+                      'is None, which will use the request\'s host_url '
+                      'attribute to populate the URL base. If Glance is '
+                      'operating behind a proxy, you will want to change '
+                      'this to represent the proxy\'s URL.')),
+]
 
 CONF = cfg.CONF
+CONF.register_opts(versions_opts)
 
 
 class Controller(object):
@@ -32,13 +44,14 @@ class Controller(object):
     def index(self, req):
         """Respond to a request for all OpenStack API versions."""
         def build_version_object(version, path, status):
+            url = CONF.public_endpoint or req.host_url
             return {
                 'id': 'v%s' % version,
                 'status': status,
                 'links': [
                     {
                         'rel': 'self',
-                        'href': '%s/%s/' % (req.host_url, path),
+                        'href': '%s/%s/' % (url, path),
                     },
                 ],
             }
@@ -46,13 +59,14 @@ class Controller(object):
         version_objs = []
         if CONF.enable_v2_api:
             version_objs.extend([
-                build_version_object(2.2, 'v2', 'CURRENT'),
+                build_version_object(2.3, 'v2', 'CURRENT'),
+                build_version_object(2.2, 'v2', 'SUPPORTED'),
                 build_version_object(2.1, 'v2', 'SUPPORTED'),
                 build_version_object(2.0, 'v2', 'SUPPORTED'),
             ])
         if CONF.enable_v1_api:
             version_objs.extend([
-                build_version_object(1.1, 'v1', 'CURRENT'),
+                build_version_object(1.1, 'v1', 'SUPPORTED'),
                 build_version_object(1.0, 'v1', 'SUPPORTED'),
             ])
 
