@@ -14,17 +14,18 @@
 #    under the License.
 
 import json
+import logging
 
 from oslo_concurrency import processutils as putils
-from oslo_log import log as logging
-from oslo_utils import encodeutils
 from oslo_utils import excutils
 from taskflow.patterns import linear_flow as lf
 
 from glance.async import utils
-from glance.i18n import _LE
+from glance import i18n
 
 
+_LE = i18n._LE
+_LI = i18n._LI
 LOG = logging.getLogger(__name__)
 
 
@@ -48,7 +49,6 @@ class _Introspect(utils.OptionalTask):
         try:
             stdout, stderr = putils.trycmd('qemu-img', 'info',
                                            '--output=json', file_path,
-                                           prlimit=utils.QEMU_IMG_PROC_LIMITS,
                                            log_errors=putils.LOG_ALL_ERRORS)
         except OSError as exc:
             # NOTE(flaper87): errno == 2 means the executable file
@@ -57,11 +57,10 @@ class _Introspect(utils.OptionalTask):
             # tasks.
             if exc.errno != 2:
                 with excutils.save_and_reraise_exception():
-                    exc_message = encodeutils.exception_to_unicode(exc)
-                    msg = _LE('Failed to execute introspection '
-                              '%(task_id)s: %(exc)s')
-                    LOG.error(msg, {'task_id': self.task_id,
-                                    'exc': exc_message})
+                    msg = (_LE('Failed to execute introspection '
+                               '%(task_id)s: %(exc)s') %
+                           {'task_id': self.task_id, 'exc': exc.message})
+                    LOG.error(msg)
             return
 
         if stderr:
@@ -72,24 +71,17 @@ class _Introspect(utils.OptionalTask):
         new_image.virtual_size = metadata.get('virtual-size', 0)
         new_image.disk_format = metadata.get('format')
         self.image_repo.save(new_image)
-        LOG.debug("%(task_id)s: Introspection successful: %(file)s",
+        LOG.debug("%(task_id)s: Introspection successful: %(file)s" %
                   {'task_id': self.task_id, 'file': file_path})
         return new_image
 
 
 def get_flow(**kwargs):
-    """Return task flow for introspecting images to obtain metadata about the
-    image.
-
-    :param task_id: Task ID
-    :param task_type: Type of the task.
-    :param image_repo: Image repository used.
-    """
     task_id = kwargs.get('task_id')
     task_type = kwargs.get('task_type')
     image_repo = kwargs.get('image_repo')
 
-    LOG.debug("Flow: %(task_type)s with ID %(id)s on %(repo)s",
+    LOG.debug("Flow: %(task_type)s with ID %(id)s on %(repo)s" %
               {'task_type': task_type, 'id': task_id, 'repo': image_repo})
 
     return lf.Flow(task_type).add(
