@@ -43,6 +43,7 @@ if os.path.exists(os.path.join(possible_topdir, 'glance', '__init__.py')):
 import glance_store
 from oslo_config import cfg
 from oslo_log import log as logging
+import oslo_messaging
 import osprofiler.notifier
 import osprofiler.web
 
@@ -75,7 +76,7 @@ def main():
 
         if cfg.CONF.profiler.enabled:
             _notifier = osprofiler.notifier.create("Messaging",
-                                                   notifier.messaging, {},
+                                                   oslo_messaging, {},
                                                    notifier.get_transport(),
                                                    "glance", "api",
                                                    cfg.CONF.bind_host)
