@@ -21,10 +21,11 @@
 Reference implementation server for Glance Registry
 """
 
-import eventlet
 import os
 import sys
 
+import eventlet
+
 # Monkey patch socket and time
 eventlet.patcher.monkey_patch(all=False, socket=True, time=True, thread=True)
 
@@ -36,28 +37,31 @@ possible_topdir = os.path.normpath(os.path.join(os.path.abspath(sys.argv[0]),
 if os.path.exists(os.path.join(possible_topdir, 'glance', '__init__.py')):
     sys.path.insert(0, possible_topdir)
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
+import oslo_messaging
 import osprofiler.notifier
 import osprofiler.web
 
 from glance.common import config
+from glance.common import utils
 from glance.common import wsgi
 from glance import notifier
-from glance.openstack.common import log
 
 CONF = cfg.CONF
 CONF.import_group("profiler", "glance.common.wsgi")
+logging.register_options(CONF)
 
 
 def main():
     try:
         config.parse_args()
         wsgi.set_eventlet_hub()
-        log.setup('glance')
+        logging.setup(CONF, 'glance')
 
         if cfg.CONF.profiler.enabled:
             _notifier = osprofiler.notifier.create("Messaging",
-                                                   notifier.messaging, {},
+                                                   oslo_messaging, {},
                                                    notifier.get_transport(),
                                                    "glance", "registry",
                                                    cfg.CONF.bind_host)
@@ -71,7 +75,7 @@ def main():
                      default_port=9191)
         server.wait()
     except RuntimeError as e:
-        sys.exit("ERROR: %s" % e)
+        sys.exit("ERROR: %s" % utils.exception_to_str(e))
 
 
 if __name__ == '__main__':
