@@ -15,6 +15,7 @@
 import datetime
 import numbers
 import re
+import types
 
 import semantic_version
 import six
@@ -282,7 +283,7 @@ class Boolean(declarative.PropertyDefinition):
 
     Maps to Boolean columns in database. Supports filtering and sorting.
     """
-    ALLOWED_TYPES = (bool,)
+    ALLOWED_TYPES = (types.BooleanType,)
     DB_TYPE = 'bool'
 
 
@@ -347,11 +348,11 @@ class Dict(declarative.DictAttributeDefinition,
         :param min_properties: minimum allowed amount of properties in the dict
         :param max_properties: maximum allowed amount of properties in the dict
         """
-        declarative.DictAttributeDefinition.__init__(
-            self,
-            properties=properties,
-            min_properties=min_properties,
-            max_properties=max_properties)
+        declarative.DictAttributeDefinition. \
+            __init__(self,
+                     properties=properties,
+                     min_properties=min_properties,
+                     max_properties=max_properties)
         declarative.PropertyDefinition.__init__(self, **kwargs)
 
 
@@ -422,7 +423,7 @@ class ArtifactReference(declarative.RelationDefinition):
         """
         super(ArtifactReference, self).__init__(**kwargs)
         if type_name is not None:
-            if isinstance(type_name, list):
+            if isinstance(type_name, types.ListType):
                 type_names = list(type_name)
                 if type_version is not None:
                     raise exc.InvalidArtifactTypePropertyDefinition(
@@ -460,7 +461,7 @@ class ArtifactReferenceList(declarative.ListAttributeDefinition,
 
     def __init__(self, references=ArtifactReference(), min_size=0,
                  max_size=None, **kwargs):
-        if isinstance(references, list):
+        if isinstance(references, types.ListType):
             raise exc.InvalidArtifactTypePropertyDefinition(
                 _("Invalid reference list specification"))
         declarative.RelationDefinition.__init__(self, **kwargs)
