@@ -19,6 +19,10 @@
 import six
 import six.moves.urllib.parse as urlparse
 
+from glance import i18n
+
+_ = i18n._
+
 _FATAL_EXCEPTION_FORMAT_ERRORS = False
 
 
@@ -106,6 +110,10 @@ class NotAuthenticated(GlanceException):
     message = _("You are not authenticated.")
 
 
+class UploadException(GlanceException):
+    message = _('Image upload problem: %s')
+
+
 class Forbidden(GlanceException):
     message = _("You are not authorized to complete this action.")
 
@@ -143,6 +151,11 @@ class ProtectedMetadefResourceTypeSystemDelete(Forbidden):
                 " a seeded-system type and cannot be deleted.")
 
 
+class ProtectedMetadefTagDelete(Forbidden):
+    message = _("Metadata definition tag %(tag_name)s is protected"
+                " and cannot be deleted.")
+
+
 class Invalid(GlanceException):
     message = _("Data supplied was not valid.")
 
@@ -151,6 +164,10 @@ class InvalidSortKey(Invalid):
     message = _("Sort key supplied was not valid.")
 
 
+class InvalidSortDir(Invalid):
+    message = _("Sort direction supplied was not valid.")
+
+
 class InvalidPropertyProtectionConfiguration(Invalid):
     message = _("Invalid configuration in property protection file.")
 
@@ -163,6 +180,10 @@ class InvalidFilterRangeValue(Invalid):
     message = _("Unable to filter using the specified range.")
 
 
+class InvalidOptionValue(Invalid):
+    message = _("Invalid value for option %(option)s: %(value)s")
+
+
 class ReadonlyProperty(Forbidden):
     message = _("Attribute '%(property)s' is read-only.")
 
@@ -299,6 +320,10 @@ class ImageLocationLimitExceeded(LimitExceeded):
                 "locations. Attempted: %(attempted)s, Maximum: %(maximum)s")
 
 
+class SIGHUPInterrupt(GlanceException):
+    message = _("System SIGHUP signal received.")
+
+
 class RPCError(GlanceException):
     message = _("%(cls)s exception was raised in the last rpc call: %(val)s")
 
@@ -307,6 +332,10 @@ class TaskException(GlanceException):
     message = _("An unknown task exception occurred")
 
 
+class BadTaskConfiguration(GlanceException):
+    message = _("Task was not configured properly")
+
+
 class TaskNotFound(TaskException, NotFound):
     message = _("Task with the given id %(task_id)s was not found")
 
@@ -369,6 +398,11 @@ class MetadefDuplicateResourceTypeAssociation(Duplicate):
                 " already exists.")
 
 
+class MetadefDuplicateTag(Duplicate):
+    message = _("A metadata tag with name=%(name)s"
+                " already exists in namespace=%(namespace_name)s.")
+
+
 class MetadefForbidden(Forbidden):
     message = _("You are not authorized to complete this action.")
 
@@ -408,6 +442,115 @@ class MetadefResourceTypeAssociationNotFound(NotFound):
                 " was not found.")
 
 
-class MetadefRecordNotFound(NotFound):
-    message = _("Metadata definition %(record_type)s record not found"
-                " for id %(id)s.")
+class MetadefTagNotFound(NotFound):
+    message = _("The metadata definition tag with"
+                " name=%(name)s was not found in"
+                " namespace=%(namespace_name)s.")
+
+
+class InvalidVersion(Invalid):
+    message = _("Version is invalid: %(reason)s")
+
+
+class InvalidArtifactTypePropertyDefinition(Invalid):
+    message = _("Invalid property definition")
+
+
+class InvalidArtifactTypeDefinition(Invalid):
+    message = _("Invalid type definition")
+
+
+class InvalidArtifactPropertyValue(Invalid):
+    message = _("Property '%(name)s' may not have value '%(val)s': %(msg)s")
+
+    def __init__(self, message=None, *args, **kwargs):
+        super(InvalidArtifactPropertyValue, self).__init__(message, *args,
+                                                           **kwargs)
+        self.name = kwargs.get('name')
+        self.value = kwargs.get('val')
+
+
+class ArtifactNotFound(NotFound):
+    message = _("Artifact with id=%(id)s was not found")
+
+
+class ArtifactForbidden(Forbidden):
+    message = _("Artifact with id=%(id)s is not accessible")
+
+
+class ArtifactDuplicateNameTypeVersion(Duplicate):
+    message = _("Artifact with the specified type, name and version"
+                " already exists")
+
+
+class InvalidArtifactStateTransition(Invalid):
+    message = _("Artifact cannot change state from %(source)s to %(target)s")
+
+
+class ArtifactDuplicateDirectDependency(Duplicate):
+    message = _("Artifact with the specified type, name and version"
+                " already has the direct dependency=%(dep)s")
+
+
+class ArtifactDuplicateTransitiveDependency(Duplicate):
+    message = _("Artifact with the specified type, name and version"
+                " already has the transitive dependency=%(dep)s")
+
+
+class ArtifactUnsupportedPropertyOperator(Invalid):
+    message = _("Operator %(op)s is not supported")
+
+
+class ArtifactUnsupportedShowLevel(Invalid):
+    message = _("Show level %(shl)s is not supported in this operation")
+
+
+class ArtifactPropertyValueNotFound(NotFound):
+    message = _("Property's %(prop)s value has not been found")
+
+
+class ArtifactInvalidProperty(Invalid):
+    message = _("Artifact has no property %(prop)s")
+
+
+class ArtifactInvalidPropertyParameter(Invalid):
+    message = _("Cannot use this parameter with the operator %(op)s")
+
+
+class ArtifactLoadError(GlanceException):
+    message = _("Cannot load artifact '%(name)s'")
+
+
+class ArtifactNonMatchingTypeName(ArtifactLoadError):
+    message = _(
+        "Plugin name '%(plugin)s' should match artifact typename '%(name)s'")
+
+
+class ArtifactPluginNotFound(NotFound):
+    message = _("No plugin for '%(name)s' has been loaded")
+
+
+class UnknownArtifactType(NotFound):
+    message = _("Artifact type with name '%(name)s' and version '%(version)s' "
+                "is not known")
+
+
+class ArtifactInvalidStateTransition(Invalid):
+    message = _("Artifact state cannot be changed from %(curr)s to %(to)s")
+
+
+class JsonPatchException(GlanceException):
+    message = _("Invalid jsonpatch request")
+
+
+class InvalidJsonPatchBody(JsonPatchException):
+    message = _("The provided body %(body)s is invalid "
+                "under given schema: %(schema)s")
+
+
+class InvalidJsonPatchPath(JsonPatchException):
+    message = _("The provided path '%(path)s' is invalid: %(explanation)s")
+
+    def __init__(self, message=None, *args, **kwargs):
+        self.explanation = kwargs.get("explanation")
+        super(InvalidJsonPatchPath, self).__init__(message, *args, **kwargs)
