@@ -15,19 +15,19 @@
 import sys
 
 import glance_store as store_api
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 import six.moves.urllib.parse as urlparse
 
 from glance.common import utils
 import glance.db as db_api
-from glance.openstack.common import gettextutils
-import glance.openstack.common.log as logging
+from glance import i18n
 from glance import scrubber
 
-_LE = gettextutils._LE
-_LW = gettextutils._LW
-
 LOG = logging.getLogger(__name__)
+_ = i18n._
+_LE = i18n._LE
+_LW = i18n._LW
 
 store_utils_opts = [
     cfg.BoolOpt('use_user_token', default=True,
