@@ -12,16 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from collections import OrderedDict
 import ConfigParser
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 
 from glance.common import exception
-from glance.openstack.common import log as logging
+from glance import i18n
+
+_ = i18n._
+_LE = i18n._LE
 
 swift_opts = [
     cfg.StrOpt('default_swift_reference',
@@ -67,8 +68,8 @@ class SwiftParams(object):
 
     def _form_default_params(self):
         default = {}
-        if CONF.swift_store_user and CONF.swift_store_key \
-                and CONF.swift_store_auth_address:
+        if (CONF.swift_store_user and CONF.swift_store_key
+           and CONF.swift_store_auth_address):
             default['user'] = CONF.swift_store_user
             default['key'] = CONF.swift_store_key
             default['auth_address'] = CONF.swift_store_auth_address
@@ -80,7 +81,7 @@ class SwiftParams(object):
             conf_file = CONF.find_file(CONF.swift_store_config_file)
             CONFIG.read(conf_file)
         except Exception as e:
-            msg = (_("swift config file %(conf_file)s:%(exc)s not found") %
+            msg = (_LE("swift config file %(conf_file)s:%(exc)s not found") %
                    {'conf_file': CONF.swift_store_config_file, 'exc': e})
             LOG.error(msg)
             raise exception.InvalidSwiftStoreConfiguration()
@@ -94,6 +95,6 @@ class SwiftParams(object):
                 reference['key'] = CONFIG.get(ref, 'key')
                 account_params[ref] = reference
             except (ValueError, SyntaxError, ConfigParser.NoOptionError) as e:
-                LOG.exception(_("Invalid format of swift store config"
-                                "cfg"))
+                LOG.exception(_LE("Invalid format of swift store config "
+                                  "cfg"))
         return account_params
