@@ -1,6 +1,7 @@
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # Copyright 2014 SoftLayer Technologies, Inc.
+# Copyright 2015 Mirantis, Inc
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -31,26 +32,29 @@ import functools
 import os
 import platform
 import re
+import stevedore
 import subprocess
 import sys
 import uuid
 
-import netaddr
 from OpenSSL import crypto
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_utils import encodeutils
+from oslo_utils import excutils
+from oslo_utils import netutils
+from oslo_utils import strutils
+import six
 from webob import exc
 
-import six
-
 from glance.common import exception
-from glance.openstack.common import excutils
-import glance.openstack.common.log as logging
-from glance.openstack.common import network_utils
-from glance.openstack.common import strutils
+from glance import i18n
 
 CONF = cfg.CONF
 
 LOG = logging.getLogger(__name__)
+_ = i18n._
+_LE = i18n._LE
 
 FEATURE_BLACKLIST = ['content-length', 'content-type', 'x-image-meta-size']
 
@@ -64,7 +68,8 @@ IMAGE_META_HEADERS = ['x-image-meta-location', 'x-image-meta-size',
                       'x-image-meta-deleted_at', 'x-image-meta-min_ram',
                       'x-image-meta-min_disk', 'x-image-meta-owner',
                       'x-image-meta-store', 'x-image-meta-id',
-                      'x-image-meta-protected', 'x-image-meta-deleted']
+                      'x-image-meta-protected', 'x-image-meta-deleted',
+                      'x-image-meta-virtual_size']
 
 GLANCE_TEST_SOCKET_FD_STR = 'GLANCE_TEST_SOCKET_FD'
 
@@ -108,7 +113,7 @@ def cooperative_iter(iter):
             yield chunk
     except Exception as err:
         with excutils.save_and_reraise_exception():
-            msg = _("Error: cooperative_iter exception %s") % err
+            msg = _LE("Error: cooperative_iter exception %s") % err
             LOG.error(msg)
 
 
@@ -126,6 +131,9 @@ def cooperative_read(fd):
     return readfn
 
 
+MAX_COOP_READER_BUFFER_SIZE = 134217728  # 128M seems like a sane buffer limit
+
+
 class CooperativeReader(object):
     """
     An eventlet thread friendly class for reading in image data.
@@ -147,19 +155,68 @@ class CooperativeReader(object):
         # is more straightforward
         if hasattr(fd, 'read'):
             self.read = cooperative_read(fd)
+        else:
+            self.iterator = None
+            self.buffer = ''
+            self.position = 0
 
     def read(self, length=None):
-        """Return the next chunk of the underlying iterator.
+        """Return the requested amount of bytes, fetching the next chunk of
+        the underlying iterator when needed.
 
         This is replaced with cooperative_read in __init__ if the underlying
         fd already supports read().
         """
-        if self.iterator is None:
-            self.iterator = self.__iter__()
-        try:
-            return self.iterator.next()
-        except StopIteration:
-            return ''
+        if length is None:
+            if len(self.buffer) - self.position > 0:
+                # if no length specified but some data exists in buffer,
+                # return that data and clear the buffer
+                result = self.buffer[self.position:]
+                self.buffer = ''
+                self.position = 0
+                return str(result)
+            else:
+                # otherwise read the next chunk from the underlying iterator
+                # and return it as a whole. Reset the buffer, as subsequent
+                # calls may specify the length
+                try:
+                    if self.iterator is None:
+                        self.iterator = self.__iter__()
+                    return self.iterator.next()
+                except StopIteration:
+                    return ''
+                finally:
+                    self.buffer = ''
+                    self.position = 0
+        else:
+            result = bytearray()
+            while len(result) < length:
+                if self.position < len(self.buffer):
+                    to_read = length - len(result)
+                    chunk = self.buffer[self.position:self.position + to_read]
+                    result.extend(chunk)
+
+                    # This check is here to prevent potential OOM issues if
+                    # this code is called with unreasonably high values of read
+                    # size. Currently it is only called from the HTTP clients
+                    # of Glance backend stores, which use httplib for data
+                    # streaming, which has readsize hardcoded to 8K, so this
+                    # check should never fire. Regardless it still worths to
+                    # make the check, as the code may be reused somewhere else.
+                    if len(result) >= MAX_COOP_READER_BUFFER_SIZE:
+                        raise exception.LimitExceeded()
+                    self.position += len(chunk)
+                else:
+                    try:
+                        if self.iterator is None:
+                            self.iterator = self.__iter__()
+                        self.buffer = self.iterator.next()
+                        self.position = 0
+                    except StopIteration:
+                        self.buffer = ''
+                        self.position = 0
+                        return str(result)
+            return str(result)
 
     def __iter__(self):
         return cooperative_iter(self.fd.__iter__())
@@ -245,21 +302,23 @@ def get_image_meta_from_headers(response):
             result[field_name] = value or None
     result['properties'] = properties
 
-    for key in ('size', 'min_disk', 'min_ram'):
+    for key, nullable in [('size', False), ('min_disk', False),
+                          ('min_ram', False), ('virtual_size', True)]:
         if key in result:
             try:
                 result[key] = int(result[key])
             except ValueError:
-                extra = (_("Cannot convert image %(key)s '%(value)s' "
-                           "to an integer.")
-                         % {'key': key, 'value': result[key]})
-                raise exception.InvalidParameterValue(value=result[key],
-                                                      param=key,
-                                                      extra_msg=extra)
-            if result[key] < 0:
-                extra = (_("Image %(key)s must be >= 0 "
-                           "('%(value)s' specified).")
-                         % {'key': key, 'value': result[key]})
+                if nullable and result[key] == str(None):
+                    result[key] = None
+                else:
+                    extra = (_("Cannot convert image %(key)s '%(value)s' "
+                               "to an integer.")
+                             % {'key': key, 'value': result[key]})
+                    raise exception.InvalidParameterValue(value=result[key],
+                                                          param=key,
+                                                          extra_msg=extra)
+            if result[key] < 0 and result[key] is not None:
+                extra = _('Cannot be a negative value.')
                 raise exception.InvalidParameterValue(value=result[key],
                                                       param=key,
                                                       extra_msg=extra)
@@ -451,10 +510,10 @@ def mutating(func):
 
 
 def setup_remote_pydev_debug(host, port):
-    error_msg = _('Error setting up the debug environment.  Verify that the'
-                  ' option pydev_worker_debug_host is pointing to a valid '
-                  'hostname or IP on which a pydev server is listening on'
-                  ' the port indicated by pydev_worker_debug_port.')
+    error_msg = _LE('Error setting up the debug environment. Verify that the'
+                    ' option pydev_worker_debug_host is pointing to a valid '
+                    'hostname or IP on which a pydev server is listening on'
+                    ' the port indicated by pydev_worker_debug_port.')
 
     try:
         try:
@@ -472,41 +531,6 @@ def setup_remote_pydev_debug(host, port):
             LOG.exception(error_msg)
 
 
-class LazyPluggable(object):
-    """A pluggable backend loaded lazily based on some value."""
-
-    def __init__(self, pivot, config_group=None, **backends):
-        self.__backends = backends
-        self.__pivot = pivot
-        self.__backend = None
-        self.__config_group = config_group
-
-    def __get_backend(self):
-        if not self.__backend:
-            if self.__config_group is None:
-                backend_name = CONF[self.__pivot]
-            else:
-                backend_name = CONF[self.__config_group][self.__pivot]
-            if backend_name not in self.__backends:
-                msg = _('Invalid backend: %s') % backend_name
-                raise exception.GlanceException(msg)
-
-            backend = self.__backends[backend_name]
-            if isinstance(backend, tuple):
-                name = backend[0]
-                fromlist = backend[1]
-            else:
-                name = backend
-                fromlist = backend
-
-            self.__backend = __import__(name, None, None, fromlist)
-        return self.__backend
-
-    def __getattr__(self, key):
-        backend = self.__get_backend()
-        return getattr(backend, key)
-
-
 def validate_key_cert(key_file, cert_file):
     try:
         error_key_name = "private key"
@@ -537,8 +561,15 @@ def validate_key_cert(key_file, cert_file):
 
     try:
         data = str(uuid.uuid4())
-        digest = "sha1"
-
+        digest = CONF.digest_algorithm
+        if digest == 'sha1':
+            LOG.warn('The FIPS (FEDERAL INFORMATION PROCESSING STANDARDS)'
+                     ' state that the SHA-1 is not suitable for'
+                     ' general-purpose digital signature applications (as'
+                     ' specified in FIPS 186-3) that require 112 bits of'
+                     ' security. The default value is sha1 in Kilo for a'
+                     ' smooth upgrade process, and it will be updated'
+                     ' with sha256 in next release(L).')
         out = crypto.sign(key, data, digest)
         crypto.verify(cert, out, data, digest)
     except crypto.Error as ce:
@@ -575,27 +606,6 @@ def is_uuid_like(val):
         return False
 
 
-def is_valid_port(port):
-    """Verify that port represents a valid port number."""
-    return str(port).isdigit() and int(port) > 0 and int(port) <= 65535
-
-
-def is_valid_ipv4(address):
-    """Verify that address represents a valid IPv4 address."""
-    try:
-        return netaddr.valid_ipv4(address)
-    except Exception:
-        return False
-
-
-def is_valid_ipv6(address):
-    """Verify that address represents a valid IPv6 address."""
-    try:
-        return netaddr.valid_ipv6(address)
-    except Exception:
-        return False
-
-
 def is_valid_hostname(hostname):
     """Verify whether a hostname (not an FQDN) is valid."""
     return re.match('^[a-zA-Z0-9-]+$', hostname) is not None
@@ -618,11 +628,11 @@ def parse_valid_host_port(host_port):
 
     try:
         try:
-            host, port = network_utils.parse_host_port(host_port)
+            host, port = netutils.parse_host_port(host_port)
         except Exception:
             raise ValueError(_('Host and port "%s" is not valid.') % host_port)
 
-        if not is_valid_port(port):
+        if not netutils.is_valid_port(port):
             raise ValueError(_('Port "%s" is not valid.') % port)
 
         # First check for valid IPv6 and IPv4 addresses, then a generic
@@ -630,7 +640,7 @@ def parse_valid_host_port(host_port):
         # should pass a very generic FQDN check. The FQDN check for letters at
         # the tail end will weed out any hilariously absurd IPv4 addresses.
 
-        if not (is_valid_ipv6(host) or is_valid_ipv4(host) or
+        if not (netutils.is_valid_ipv6(host) or netutils.is_valid_ipv4(host) or
                 is_valid_hostname(host) or is_valid_fqdn(host)):
             raise ValueError(_('Host "%s" is not valid.') % host)
 
@@ -654,4 +664,74 @@ def exception_to_str(exc):
         except UnicodeError:
             error = ("Caught '%(exception)s' exception." %
                      {"exception": exc.__class__.__name__})
-    return strutils.safe_encode(error, errors='ignore')
+    return encodeutils.safe_encode(error, errors='ignore')
+
+
+try:
+    REGEX_4BYTE_UNICODE = re.compile(u'[\U00010000-\U0010ffff]')
+except re.error:
+    # UCS-2 build case
+    REGEX_4BYTE_UNICODE = re.compile(u'[\uD800-\uDBFF][\uDC00-\uDFFF]')
+
+
+def no_4byte_params(f):
+    """
+    Checks that no 4 byte unicode characters are allowed
+    in dicts' keys/values and string's parameters
+    """
+    def wrapper(*args, **kwargs):
+
+        def _is_match(some_str):
+            return (isinstance(some_str, unicode) and
+                    REGEX_4BYTE_UNICODE.findall(some_str) != [])
+
+        def _check_dict(data_dict):
+            # a dict of dicts has to be checked recursively
+            for key, value in data_dict.iteritems():
+                if isinstance(value, dict):
+                    _check_dict(value)
+                else:
+                    if _is_match(key):
+                        msg = _("Property names can't contain 4 byte unicode.")
+                        raise exception.Invalid(msg)
+                    if _is_match(value):
+                        msg = (_("%s can't contain 4 byte unicode characters.")
+                               % key.title())
+                        raise exception.Invalid(msg)
+
+        for data_dict in [arg for arg in args if isinstance(arg, dict)]:
+            _check_dict(data_dict)
+        # now check args for str values
+        for arg in args:
+            if _is_match(arg):
+                msg = _("Param values can't contain 4 byte unicode.")
+                raise exception.Invalid(msg)
+        # check kwargs as well, as params are passed as kwargs via
+        # registry calls
+        _check_dict(kwargs)
+        return f(*args, **kwargs)
+    return wrapper
+
+
+def stash_conf_values():
+    """
+    Make a copy of some of the current global CONF's settings.
+    Allows determining if any of these values have changed
+    when the config is reloaded.
+    """
+    conf = {}
+    conf['bind_host'] = CONF.bind_host
+    conf['bind_port'] = CONF.bind_port
+    conf['tcp_keepidle'] = CONF.cert_file
+    conf['backlog'] = CONF.backlog
+    conf['key_file'] = CONF.key_file
+    conf['cert_file'] = CONF.cert_file
+
+    return conf
+
+
+def get_search_plugins():
+    namespace = 'glance.search.index_backend'
+    ext_manager = stevedore.extension.ExtensionManager(
+        namespace, invoke_on_load=True)
+    return ext_manager.extensions
