@@ -13,16 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_log import log as logging
 import six.moves.urllib.parse as urlparse
 import sqlalchemy
 
 from glance.common import exception
 from glance.common import utils
-from glance.openstack.common import gettextutils
-import glance.openstack.common.log as logging
+from glance import i18n
 
 LOG = logging.getLogger(__name__)
-_LE = gettextutils._LE
+_ = i18n._
+_LE = i18n._LE
 
 
 def upgrade(migrate_engine):
@@ -54,9 +55,9 @@ def migrate_location_credentials(migrate_engine, to_quoted):
     for image in images:
         try:
             fixed_uri = legacy_parse_uri(image['location'], to_quoted)
-            images_table.update()\
-                        .where(images_table.c.id == image['id'])\
-                        .values(location=fixed_uri).execute()
+            images_table.update().where(
+                images_table.c.id == image['id']).values(
+                    location=fixed_uri).execute()
         except exception.BadStoreUri as e:
             reason = utils.exception_to_str(e)
             msg = _LE("Invalid store uri for image: %(image_id)s. "
