@@ -20,34 +20,28 @@ SQLAlchemy models for glance data
 
 import uuid
 
-from oslo.db.sqlalchemy import models
+from oslo.serialization import jsonutils
+from oslo_db.sqlalchemy import models
+from oslo_utils import timeutils
 from sqlalchemy import BigInteger
 from sqlalchemy import Boolean
 from sqlalchemy import Column
 from sqlalchemy import DateTime
-from sqlalchemy.ext.compiler import compiles
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import ForeignKey
 from sqlalchemy import Index
 from sqlalchemy import Integer
 from sqlalchemy.orm import backref, relationship
+from sqlalchemy import sql
 from sqlalchemy import String
 from sqlalchemy import Text
 from sqlalchemy.types import TypeDecorator
 from sqlalchemy import UniqueConstraint
 
-from glance.openstack.common import jsonutils
-from glance.openstack.common import timeutils
-
 
 BASE = declarative_base()
 
 
-@compiles(BigInteger, 'sqlite')
-def compile_big_int_sqlite(type_, compiler, **kw):
-    return 'INTEGER'
-
-
 class JSONEncodedDict(TypeDecorator):
     """Represents an immutable structure as a json-encoded string"""
 
@@ -83,7 +77,7 @@ class GlanceBase(models.ModelBase, models.TimestampMixin):
     #                  required and make changes in oslo (if required) or
     #                  in glance (if not).
     updated_at = Column(DateTime, default=lambda: timeutils.utcnow(),
-                        nullable=False, onupdate=lambda: timeutils.utcnow())
+                        nullable=True, onupdate=lambda: timeutils.utcnow())
     # TODO(boris-42): Use SoftDeleteMixin instead of deleted Column after
     #                 migration that provides UniqueConstraints and change
     #                 type of this column.
@@ -128,15 +122,16 @@ class Image(BASE, GlanceBase):
     name = Column(String(255))
     disk_format = Column(String(20))
     container_format = Column(String(20))
-    size = Column(BigInteger)
-    virtual_size = Column(BigInteger)
+    size = Column(BigInteger().with_variant(Integer, "sqlite"))
+    virtual_size = Column(BigInteger().with_variant(Integer, "sqlite"))
     status = Column(String(30), nullable=False)
     is_public = Column(Boolean, nullable=False, default=False)
     checksum = Column(String(32))
     min_disk = Column(Integer, nullable=False, default=0)
     min_ram = Column(Integer, nullable=False, default=0)
     owner = Column(String(255))
-    protected = Column(Boolean, nullable=False, default=False)
+    protected = Column(Boolean, nullable=False, default=False,
+                       server_default=sql.expression.false())
 
 
 class ImageProperty(BASE, GlanceBase):
@@ -183,7 +178,7 @@ class ImageLocation(BASE, GlanceBase):
     image = relationship(Image, backref=backref('locations'))
     value = Column(Text(), nullable=False)
     meta_data = Column(JSONEncodedDict(), default={})
-    status = Column(String(30), default='active', nullable=False)
+    status = Column(String(30), server_default='active', nullable=False)
 
 
 class ImageMember(BASE, GlanceBase):
@@ -207,7 +202,8 @@ class ImageMember(BASE, GlanceBase):
 
     member = Column(String(255), nullable=False)
     can_share = Column(Boolean, nullable=False, default=False)
-    status = Column(String(20), nullable=False, default="pending")
+    status = Column(String(20), nullable=False, default="pending",
+                    server_default='pending')
 
 
 class Task(BASE, GlanceBase):
@@ -221,8 +217,8 @@ class Task(BASE, GlanceBase):
 
     id = Column(String(36), primary_key=True,
                 default=lambda: str(uuid.uuid4()))
-    type = Column(String(30))
-    status = Column(String(30))
+    type = Column(String(30), nullable=False)
+    status = Column(String(30), nullable=False)
     owner = Column(String(255), nullable=False)
     expires_at = Column(DateTime, nullable=True)
 
@@ -238,7 +234,7 @@ class TaskInfo(BASE, models.ModelBase):
 
     task = relationship(Task, backref=backref('info', uselist=False))
 
-    #NOTE(nikhil): input and result are stored as text in the DB.
+    # NOTE(nikhil): input and result are stored as text in the DB.
     # SQLAlchemy marshals the data to/from JSON using custom type
     # JSONEncodedDict. It uses simplejson underneath.
     input = Column(JSONEncodedDict())
