@@ -44,7 +44,7 @@ _LW = i18n._LW
 class ArtifactBase(models.ModelBase, models.TimestampMixin):
     """Base class for Artifact Models."""
 
-    __table_args__ = {'mysql_engine': 'InnoDB', 'mysql_charset': 'utf8'}
+    __table_args__ = {'mysql_engine': 'InnoDB'}
     __table_initialized__ = False
     __protected_attributes__ = set([
         "created_at", "updated_at"])
@@ -102,7 +102,7 @@ class Artifact(BASE, ArtifactBase):
         Index('ix_artifact_state', 'state'),
         Index('ix_artifact_owner', 'owner'),
         Index('ix_artifact_visibility', 'visibility'),
-        {'mysql_engine': 'InnoDB', 'mysql_charset': 'utf8'})
+        {'mysql_engine': 'InnoDB'})
 
     __protected_attributes__ = ArtifactBase.__protected_attributes__.union(
         set(['published_at', 'deleted_at']))
@@ -116,15 +116,13 @@ class Artifact(BASE, ArtifactBase):
     type_version_suffix = Column(String(255))
     type_version_meta = Column(String(255))
     type_version = composite(semver_db.DBVersion, type_version_prefix,
-                             type_version_suffix, type_version_meta,
-                             comparator_factory=semver_db.VersionComparator)
+                             type_version_suffix, type_version_meta)
     version_prefix = Column(BigInteger().with_variant(Integer, "sqlite"),
                             nullable=False)
     version_suffix = Column(String(255))
     version_meta = Column(String(255))
     version = composite(semver_db.DBVersion, version_prefix,
-                        version_suffix, version_meta,
-                        comparator_factory=semver_db.VersionComparator)
+                        version_suffix, version_meta)
     description = Column(Text)
     visibility = Column(String(32), nullable=False)
     state = Column(String(32), nullable=False)
@@ -223,7 +221,7 @@ class ArtifactDependency(BASE, ArtifactBase):
                             'artifact_dest'),
                       Index('ix_artifact_dependencies_direct_dependencies',
                             'artifact_source', 'is_direct'),
-                      {'mysql_engine': 'InnoDB', 'mysql_charset': 'utf8'})
+                      {'mysql_engine': 'InnoDB'})
 
     id = Column(String(36), primary_key=True, nullable=False,
                 default=lambda: str(uuid.uuid4()))
@@ -252,7 +250,7 @@ class ArtifactTag(BASE, ArtifactBase):
     __table_args__ = (Index('ix_artifact_tags_artifact_id', 'artifact_id'),
                       Index('ix_artifact_tags_artifact_id_tag_value',
                             'artifact_id', 'value'),
-                      {'mysql_engine': 'InnoDB', 'mysql_charset': 'utf8'},)
+                      {'mysql_engine': 'InnoDB'},)
 
     id = Column(String(36), primary_key=True, nullable=False,
                 default=lambda: str(uuid.uuid4()))
@@ -269,7 +267,7 @@ class ArtifactProperty(BASE, ArtifactBase):
     __table_args__ = (
         Index('ix_artifact_properties_artifact_id', 'artifact_id'),
         Index('ix_artifact_properties_name', 'name'),
-        {'mysql_engine': 'InnoDB', 'mysql_charset': 'utf8'},)
+        {'mysql_engine': 'InnoDB'},)
     id = Column(String(36), primary_key=True, nullable=False,
                 default=lambda: str(uuid.uuid4()))
     artifact_id = Column(String(36), ForeignKey('artifacts.id'),
@@ -291,7 +289,7 @@ class ArtifactBlob(BASE, ArtifactBase):
     __table_args__ = (
         Index('ix_artifact_blobs_artifact_id', 'artifact_id'),
         Index('ix_artifact_blobs_name', 'name'),
-        {'mysql_engine': 'InnoDB', 'mysql_charset': 'utf8'},)
+        {'mysql_engine': 'InnoDB'},)
     id = Column(String(36), primary_key=True, nullable=False,
                 default=lambda: str(uuid.uuid4()))
     artifact_id = Column(String(36), ForeignKey('artifacts.id'),
@@ -311,7 +309,7 @@ class ArtifactBlobLocation(BASE, ArtifactBase):
     __tablename__ = 'artifact_blob_locations'
     __table_args__ = (Index('ix_artifact_blob_locations_blob_id',
                             'blob_id'),
-                      {'mysql_engine': 'InnoDB', 'mysql_charset': 'utf8'})
+                      {'mysql_engine': 'InnoDB'})
 
     id = Column(String(36), primary_key=True, nullable=False,
                 default=lambda: str(uuid.uuid4()))
