@@ -58,20 +58,21 @@ import os
 import stat
 import time
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_utils import excutils
 import xattr
 
 from glance.common import exception
 from glance.common import utils
+from glance import i18n
 from glance.image_cache.drivers import base
-from glance.openstack.common import excutils
-from glance.openstack.common import gettextutils
-import glance.openstack.common.log as logging
 
 LOG = logging.getLogger(__name__)
-_LE = gettextutils._LE
-_LI = gettextutils._LI
-_LW = gettextutils._LW
+_ = i18n._
+_LE = i18n._LE
+_LI = i18n._LI
+_LW = i18n._LW
 
 CONF = cfg.CONF
 
@@ -106,11 +107,11 @@ class Driver(base.Driver):
             set_xattr(fake_image_filepath, 'hits', '1')
         except IOError as e:
             if e.errno == errno.EOPNOTSUPP:
-                msg = (_LE("The device housing the image cache directory "
-                           "%(image_cache_dir)s does not support xattr. It is"
-                           " likely you need to edit your fstab and add the "
-                           "user_xattr option to the appropriate line for the"
-                           " device housing the cache directory.") %
+                msg = (_("The device housing the image cache directory "
+                         "%(image_cache_dir)s does not support xattr. It is"
+                         " likely you need to edit your fstab and add the "
+                         "user_xattr option to the appropriate line for the"
+                         " device housing the cache directory.") %
                        {'image_cache_dir': image_cache_dir})
                 LOG.error(msg)
                 raise exception.BadDriverConfiguration(driver_name="xattr",
@@ -277,7 +278,7 @@ class Driver(base.Driver):
             LOG.debug("Fetch finished, moving "
                       "'%(incomplete_path)s' to '%(final_path)s'",
                       dict(incomplete_path=incomplete_path,
-                      final_path=final_path))
+                           final_path=final_path))
             os.rename(incomplete_path, final_path)
 
             # Make sure that we "pop" the image from the queue...
@@ -376,7 +377,7 @@ class Driver(base.Driver):
             items.append((mtime, os.path.basename(path)))
 
         items.sort()
-        return [image_id for (mtime, image_id) in items]
+        return [image_id for (modtime, image_id) in items]
 
     def _reap_old_files(self, dirpath, entry_type, grace=None):
         now = time.time()
