@@ -23,14 +23,8 @@ __all__ = [
 import copy
 import itertools
 
-from glance.openstack.common import gettextutils
-
-# TODO(zhiyan): Remove translation from in-line
-# help message of option definition code.
-gettextutils.install('glance', lazy=False)
-
 import glance.api.middleware.context
-import glance.api.policy
+import glance.api.versions
 import glance.common.config
 import glance.common.location_strategy
 import glance.common.location_strategy.store_type
@@ -40,22 +34,16 @@ import glance.common.wsgi
 import glance.image_cache
 import glance.image_cache.drivers.sqlite
 import glance.notifier
-import glance.openstack.common.lockutils
-import glance.openstack.common.log
 import glance.registry
 import glance.registry.client
 import glance.registry.client.v1.api
 import glance.scrubber
 
 
-_global_opt_lists = [
-    glance.openstack.common.log.common_cli_opts,
-    glance.openstack.common.log.logging_cli_opts,
-]
 _api_opts = [
-    (None, list(itertools.chain(*(_global_opt_lists + [
+    (None, list(itertools.chain(
         glance.api.middleware.context.context_opts,
-        glance.api.policy.policy_opts,
+        glance.api.versions.versions_opts,
         glance.common.config.common_opts,
         glance.common.location_strategy.location_strategy_opts,
         glance.common.property_utils.property_opts,
@@ -70,8 +58,7 @@ _api_opts = [
         glance.registry.client.registry_client_ctx_opts,
         glance.registry.client.registry_client_opts,
         glance.registry.client.v1.api.registry_client_ctx_opts,
-        glance.openstack.common.lockutils.util_opts,
-        glance.scrubber.scrubber_opts])))),
+        glance.scrubber.scrubber_opts))),
     ('image_format', glance.common.config.image_format_opts),
     ('task', glance.common.config.task_opts),
     ('store_type_location_strategy',
@@ -79,43 +66,38 @@ _api_opts = [
     ('paste_deploy', glance.common.config.paste_deploy_opts)
 ]
 _registry_opts = [
-    (None, list(itertools.chain(*(_global_opt_lists + [
+    (None, list(itertools.chain(
         glance.api.middleware.context.context_opts,
-        glance.api.policy.policy_opts,
         glance.common.config.common_opts,
         glance.common.wsgi.bind_opts,
         glance.common.wsgi.socket_opts,
-        glance.common.wsgi.eventlet_opts])))),
+        glance.common.wsgi.eventlet_opts))),
     ('paste_deploy', glance.common.config.paste_deploy_opts)
 ]
 _scrubber_opts = [
-    (None, list(itertools.chain(*(_global_opt_lists + [
-        glance.api.policy.policy_opts,
+    (None, list(itertools.chain(
         glance.common.config.common_opts,
-        glance.openstack.common.lockutils.util_opts,
         glance.scrubber.scrubber_opts,
         glance.scrubber.scrubber_cmd_opts,
         glance.scrubber.scrubber_cmd_cli_opts,
         glance.registry.client.registry_client_ctx_opts,
-        glance.registry.registry_addr_opts])))),
+        glance.registry.registry_addr_opts))),
 ]
 _cache_opts = [
-    (None, list(itertools.chain(*(_global_opt_lists + [
-        glance.api.policy.policy_opts,
+    (None, list(itertools.chain(
         glance.common.config.common_opts,
         glance.image_cache.drivers.sqlite.sqlite_opts,
         glance.image_cache.image_cache_opts,
         glance.registry.registry_addr_opts,
-        glance.registry.client.registry_client_ctx_opts])))),
+        glance.registry.client.registry_client_ctx_opts))),
 ]
 _manage_opts = [
-    (None, list(itertools.chain(*(_global_opt_lists + [
-        glance.common.config.manage_opts]))))
+    (None, [])
 ]
 
 
 def list_api_opts():
-    """Return a list of oslo.config options available in Glance API service.
+    """Return a list of oslo_config options available in Glance API service.
 
     Each element of the list is a tuple. The first element is the name of the
     group under which the list of elements in the second element will be
@@ -123,7 +105,7 @@ def list_api_opts():
     config files.
 
     This function is also discoverable via the 'glance.api' entry point
-    under the 'oslo.config.opts' namespace.
+    under the 'oslo_config.opts' namespace.
 
     The purpose of this is to allow tools like the Oslo sample config file
     generator to discover the options exposed to users by Glance.
@@ -135,26 +117,26 @@ def list_api_opts():
 
 
 def list_registry_opts():
-    """Return a list of oslo.config options available in Glance Registry
+    """Return a list of oslo_config options available in Glance Registry
     service.
     """
     return [(g, copy.deepcopy(o)) for g, o in _registry_opts]
 
 
 def list_scrubber_opts():
-    """Return a list of oslo.config options available in Glance Scrubber
+    """Return a list of oslo_config options available in Glance Scrubber
     service.
     """
     return [(g, copy.deepcopy(o)) for g, o in _scrubber_opts]
 
 
 def list_cache_opts():
-    """Return a list of oslo.config options available in Glance Cache
+    """Return a list of oslo_config options available in Glance Cache
     service.
     """
     return [(g, copy.deepcopy(o)) for g, o in _cache_opts]
 
 
 def list_manage_opts():
-    """Return a list of oslo.config options available in Glance manage."""
+    """Return a list of oslo_config options available in Glance manage."""
     return [(g, copy.deepcopy(o)) for g, o in _manage_opts]
