@@ -17,14 +17,15 @@
 
 import datetime
 import hashlib
-import httplib2
 import os
 import sys
 
-from six.moves import xrange
+import httplib2
+from oslo.serialization import jsonutils
+from oslo_utils import units
+# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
+from six.moves import range
 
-from glance.openstack.common import jsonutils
-from glance.openstack.common import units
 from glance.tests import functional
 from glance.tests.utils import execute
 from glance.tests.utils import minimal_headers
@@ -60,12 +61,12 @@ class TestBinGlanceCacheManage(functional.FunctionalTest):
         http = httplib2.Http()
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
-        self.assertEqual(response.status, 201)
+        self.assertEqual(201, response.status)
         data = jsonutils.loads(content)
-        self.assertEqual(data['image']['checksum'],
-                         hashlib.md5(image_data).hexdigest())
-        self.assertEqual(data['image']['size'], FIVE_KB)
-        self.assertEqual(data['image']['name'], name)
+        self.assertEqual(hashlib.md5(image_data).hexdigest(),
+                         data['image']['checksum'])
+        self.assertEqual(FIVE_KB, data['image']['size'])
+        self.assertEqual(name, data['image']['name'])
         self.assertTrue(data['image']['is_public'])
         return data['image']['id']
 
@@ -136,14 +137,14 @@ class TestBinGlanceCacheManage(functional.FunctionalTest):
 
         # Add a few images and cache the second one of them
         # by GETing the image...
-        for x in xrange(4):
+        for x in range(4):
             ids[x] = self.add_image("Image%s" % x)
 
         path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", api_port,
                                               ids[1])
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         self.assertTrue(self.is_image_cached(ids[1]),
                         "%s is not cached." % ids[1])
@@ -183,7 +184,7 @@ class TestBinGlanceCacheManage(functional.FunctionalTest):
 
         # Add a few images and cache the second one of them
         # by GETing the image...
-        for x in xrange(4):
+        for x in range(4):
             ids[x] = self.add_image("Image%s" % x)
 
         # Queue second image and then cache it
@@ -281,7 +282,7 @@ log_file = %(log_file)s
         self.assertTrue('No queued images' in out.strip())
 
         # Queue all images
-        for x in xrange(4):
+        for x in range(4):
             cmd = ("%s --port=%d --force "
                    "queue-image %s") % (exe_cmd, api_port, ids[x])
 
