@@ -27,19 +27,19 @@ import sys
 import time
 
 import httplib2
-from six.moves import xrange
+from oslo.serialization import jsonutils
+from oslo_utils import units
+# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
+from six.moves import range
 
-from glance.openstack.common import jsonutils
-from glance.openstack.common import units
 from glance.tests import functional
+from glance.tests.functional.store_utils import get_http_uri
+from glance.tests.functional.store_utils import setup_http
 from glance.tests.utils import execute
 from glance.tests.utils import minimal_headers
 from glance.tests.utils import skip_if_disabled
 from glance.tests.utils import xattr_writes_supported
 
-from glance.tests.functional.store_utils import get_http_uri
-from glance.tests.functional.store_utils import setup_http
-
 FIVE_KB = 5 * units.Ki
 
 
@@ -61,12 +61,12 @@ class BaseCacheMiddlewareTest(object):
         http = httplib2.Http()
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
-        self.assertEqual(response.status, 201)
+        self.assertEqual(201, response.status)
         data = jsonutils.loads(content)
-        self.assertEqual(data['image']['checksum'],
-                         hashlib.md5(image_data).hexdigest())
-        self.assertEqual(data['image']['size'], FIVE_KB)
-        self.assertEqual(data['image']['name'], "Image1")
+        self.assertEqual(hashlib.md5(image_data).hexdigest(),
+                         data['image']['checksum'])
+        self.assertEqual(FIVE_KB, data['image']['size'])
+        self.assertEqual("Image1", data['image']['name'])
         self.assertTrue(data['image']['is_public'])
 
         image_id = data['image']['id']
@@ -81,7 +81,7 @@ class BaseCacheMiddlewareTest(object):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         # Verify image now in cache
         image_cached_path = os.path.join(self.api_server.image_cache_dir,
@@ -111,7 +111,7 @@ class BaseCacheMiddlewareTest(object):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         self.assertFalse(os.path.exists(image_cached_path))
 
@@ -136,7 +136,7 @@ class BaseCacheMiddlewareTest(object):
         response, content = http.request(path, 'POST',
                                          headers=headers,
                                          body=jsonutils.dumps(image_entity))
-        self.assertEqual(response.status, 201)
+        self.assertEqual(201, response.status)
         data = jsonutils.loads(content)
         image_id = data['id']
 
@@ -147,7 +147,7 @@ class BaseCacheMiddlewareTest(object):
         response, content = http.request(path, 'PUT',
                                          headers=headers,
                                          body=image_data)
-        self.assertEqual(response.status, 204)
+        self.assertEqual(204, response.status)
 
         # Verify image not in cache
         image_cached_path = os.path.join(self.api_server.image_cache_dir,
@@ -157,7 +157,7 @@ class BaseCacheMiddlewareTest(object):
         # Grab the image
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         # Verify image now in cache
         image_cached_path = os.path.join(self.api_server.image_cache_dir,
@@ -169,7 +169,7 @@ class BaseCacheMiddlewareTest(object):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 204)
+        self.assertEqual(204, response.status)
 
         self.assertFalse(os.path.exists(image_cached_path))
 
@@ -195,9 +195,9 @@ class BaseCacheMiddlewareTest(object):
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'POST', headers=headers)
-        self.assertEqual(response.status, 201)
+        self.assertEqual(201, response.status)
         data = jsonutils.loads(content)
-        self.assertEqual(data['image']['size'], FIVE_KB)
+        self.assertEqual(FIVE_KB, data['image']['size'])
 
         image_id = data['image']['id']
         path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
@@ -206,14 +206,14 @@ class BaseCacheMiddlewareTest(object):
         # Grab the image
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         # Grab the image again to ensure it can be served out from
         # cache with the correct size
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
-        self.assertEqual(int(response['content-length']), FIVE_KB)
+        self.assertEqual(200, response.status)
+        self.assertEqual(FIVE_KB, int(response['content-length']))
 
         self.stop_servers()
 
@@ -233,12 +233,12 @@ class BaseCacheMiddlewareTest(object):
         http = httplib2.Http()
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
-        self.assertEqual(response.status, 201)
+        self.assertEqual(201, response.status)
         data = jsonutils.loads(content)
-        self.assertEqual(data['image']['checksum'],
-                         hashlib.md5(image_data).hexdigest())
-        self.assertEqual(data['image']['size'], FIVE_KB)
-        self.assertEqual(data['image']['name'], "Image1")
+        self.assertEqual(hashlib.md5(image_data).hexdigest(),
+                         data['image']['checksum'])
+        self.assertEqual(FIVE_KB, data['image']['size'])
+        self.assertEqual("Image1", data['image']['name'])
         self.assertTrue(data['image']['is_public'])
 
         image_id = data['image']['id']
@@ -257,7 +257,7 @@ class BaseCacheMiddlewareTest(object):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 403)
+        self.assertEqual(403, response.status)
 
         # Now, we delete the image from the server and verify that
         # the image cache no longer contains the deleted image
@@ -265,7 +265,7 @@ class BaseCacheMiddlewareTest(object):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         self.assertFalse(os.path.exists(image_cached_path))
 
@@ -293,7 +293,7 @@ class BaseCacheMiddlewareTest(object):
         response, content = http.request(path, 'POST',
                                          headers=headers,
                                          body=jsonutils.dumps(image_entity))
-        self.assertEqual(response.status, 201)
+        self.assertEqual(201, response.status)
         data = jsonutils.loads(content)
         image_id = data['id']
 
@@ -304,7 +304,7 @@ class BaseCacheMiddlewareTest(object):
         response, content = http.request(path, 'PUT',
                                          headers=headers,
                                          body=image_data)
-        self.assertEqual(response.status, 204)
+        self.assertEqual(204, response.status)
 
         # Verify image not in cache
         image_cached_path = os.path.join(self.api_server.image_cache_dir,
@@ -318,7 +318,7 @@ class BaseCacheMiddlewareTest(object):
         # Grab the image
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 403)
+        self.assertEqual(403, response.status)
 
         # Now, we delete the image from the server and verify that
         # the image cache no longer contains the deleted image
@@ -326,7 +326,101 @@ class BaseCacheMiddlewareTest(object):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 204)
+        self.assertEqual(204, response.status)
+
+        self.assertFalse(os.path.exists(image_cached_path))
+
+        self.stop_servers()
+
+    @skip_if_disabled
+    def test_cache_middleware_trans_with_deactivated_image(self):
+        """
+        Ensure the image v1/v2 API image transfer forbids downloading
+        deactivated images.
+        Image deactivation is not available in v1. So, we'll deactivate the
+        image using v2 but test image transfer with both v1 and v2.
+        """
+        self.cleanup()
+        self.start_servers(**self.__dict__.copy())
+
+        # Add an image and verify a 200 OK is returned
+        image_data = "*" * FIVE_KB
+        headers = minimal_headers('Image1')
+        path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
+        http = httplib2.Http()
+        response, content = http.request(path, 'POST', headers=headers,
+                                         body=image_data)
+        self.assertEqual(201, response.status)
+        data = jsonutils.loads(content)
+        self.assertEqual(hashlib.md5(image_data).hexdigest(),
+                         data['image']['checksum'])
+        self.assertEqual(FIVE_KB, data['image']['size'])
+        self.assertEqual("Image1", data['image']['name'])
+        self.assertTrue(data['image']['is_public'])
+
+        image_id = data['image']['id']
+
+        # Grab the image
+        path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
+                                              image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'GET')
+        self.assertEqual(200, response.status)
+
+        # Verify image in cache
+        image_cached_path = os.path.join(self.api_server.image_cache_dir,
+                                         image_id)
+        self.assertTrue(os.path.exists(image_cached_path))
+
+        # Deactivate the image using v2
+        path = "http://%s:%d/v2/images/%s/actions/deactivate"
+        path = path % ("127.0.0.1", self.api_port, image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'POST')
+        self.assertEqual(204, response.status)
+
+        # Download the image with v1. Ensure it is forbidden
+        path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
+                                              image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'GET')
+        self.assertEqual(403, response.status)
+
+        # Download the image with v2. Ensure it is forbidden
+        path = "http://%s:%d/v2/images/%s/file" % ("127.0.0.1", self.api_port,
+                                                   image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'GET')
+        self.assertEqual(403, response.status)
+
+        # Reactivate the image using v2
+        path = "http://%s:%d/v2/images/%s/actions/reactivate"
+        path = path % ("127.0.0.1", self.api_port, image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'POST')
+        self.assertEqual(204, response.status)
+
+        # Download the image with v1. Ensure it is allowed
+        path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
+                                              image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'GET')
+        self.assertEqual(200, response.status)
+
+        # Download the image with v2. Ensure it is allowed
+        path = "http://%s:%d/v2/images/%s/file" % ("127.0.0.1", self.api_port,
+                                                   image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'GET')
+        self.assertEqual(200, response.status)
+
+        # Now, we delete the image from the server and verify that
+        # the image cache no longer contains the deleted image
+        path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
+                                              image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'DELETE')
+        self.assertEqual(200, response.status)
 
         self.assertFalse(os.path.exists(image_cached_path))
 
@@ -341,7 +435,7 @@ class BaseCacheManageMiddlewareTest(object):
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
         data = jsonutils.loads(content)
         self.assertTrue('images' in data)
         self.assertEqual(0, len(data['images']))
@@ -358,12 +452,12 @@ class BaseCacheManageMiddlewareTest(object):
         http = httplib2.Http()
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
-        self.assertEqual(response.status, 201)
+        self.assertEqual(201, response.status)
         data = jsonutils.loads(content)
-        self.assertEqual(data['image']['checksum'],
-                         hashlib.md5(image_data).hexdigest())
-        self.assertEqual(data['image']['size'], FIVE_KB)
-        self.assertEqual(data['image']['name'], name)
+        self.assertEqual(hashlib.md5(image_data).hexdigest(),
+                         data['image']['checksum'])
+        self.assertEqual(FIVE_KB, data['image']['size'])
+        self.assertEqual(name, data['image']['name'])
         self.assertTrue(data['image']['is_public'])
         return data['image']['id']
 
@@ -374,11 +468,11 @@ class BaseCacheManageMiddlewareTest(object):
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         self.assertTrue('cached_images' in data)
-        self.assertEqual(data['cached_images'], [])
+        self.assertEqual([], data['cached_images'])
 
     @skip_if_disabled
     def test_user_not_authorized(self):
@@ -398,13 +492,13 @@ class BaseCacheManageMiddlewareTest(object):
                                               image_id1)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         # Verify image now in cache
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         self.assertTrue('cached_images' in data)
@@ -421,27 +515,27 @@ class BaseCacheManageMiddlewareTest(object):
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 403)
+        self.assertEqual(403, response.status)
 
         # Verify an unprivileged user cannot delete images from the cache
         path = "http://%s:%d/v1/cached_images/%s" % ("127.0.0.1",
                                                      self.api_port, image_id1)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 403)
+        self.assertEqual(403, response.status)
 
         # Verify an unprivileged user cannot delete all cached images
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 403)
+        self.assertEqual(403, response.status)
 
         # Verify an unprivileged user cannot queue an image
         path = "http://%s:%d/v1/queued_images/%s" % ("127.0.0.1",
                                                      self.api_port, image_id2)
         http = httplib2.Http()
         response, content = http.request(path, 'PUT')
-        self.assertEqual(response.status, 403)
+        self.assertEqual(403, response.status)
 
         self.stop_servers()
 
@@ -466,13 +560,13 @@ class BaseCacheManageMiddlewareTest(object):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         # Verify image now in cache
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         self.assertTrue('cached_images' in data)
@@ -498,13 +592,13 @@ class BaseCacheManageMiddlewareTest(object):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         # Verify image hits increased in output of manage GET
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         self.assertTrue('cached_images' in data)
@@ -529,7 +623,7 @@ class BaseCacheManageMiddlewareTest(object):
         ids = {}
 
         # Add a bunch of images...
-        for x in xrange(4):
+        for x in range(4):
             ids[x] = self.add_image("Image%s" % str(x))
 
         # Verify no images in cached_images because no image has been hit
@@ -537,19 +631,19 @@ class BaseCacheManageMiddlewareTest(object):
         self.verify_no_cached_images()
 
         # Grab the images, essentially caching them...
-        for x in xrange(4):
+        for x in range(4):
             path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
                                                   ids[x])
             http = httplib2.Http()
             response, content = http.request(path, 'GET')
-            self.assertEqual(response.status, 200,
+            self.assertEqual(200, response.status,
                              "Failed to find image %s" % ids[x])
 
         # Verify images now in cache
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         self.assertTrue('cached_images' in data)
@@ -557,7 +651,7 @@ class BaseCacheManageMiddlewareTest(object):
         cached_images = data['cached_images']
         self.assertEqual(4, len(cached_images))
 
-        for x in xrange(4, 0):  # Cached images returned last modified order
+        for x in range(4, 0):  # Cached images returned last modified order
             self.assertEqual(ids[x], cached_images[x]['image_id'])
             self.assertEqual(0, cached_images[x]['hits'])
 
@@ -566,12 +660,12 @@ class BaseCacheManageMiddlewareTest(object):
                                                      self.api_port, ids[2])
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         self.assertTrue('cached_images' in data)
@@ -584,12 +678,12 @@ class BaseCacheManageMiddlewareTest(object):
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         self.assertTrue('cached_images' in data)
@@ -613,19 +707,19 @@ class BaseCacheManageMiddlewareTest(object):
         NUM_IMAGES = 4
 
         # Add and then queue some images
-        for x in xrange(NUM_IMAGES):
+        for x in range(NUM_IMAGES):
             ids[x] = self.add_image("Image%s" % str(x))
             path = "http://%s:%d/v1/queued_images/%s" % ("127.0.0.1",
                                                          self.api_port, ids[x])
             http = httplib2.Http()
             response, content = http.request(path, 'PUT')
-            self.assertEqual(response.status, 200)
+            self.assertEqual(200, response.status)
 
         # Delete all queued images
         path = "http://%s:%d/v1/queued_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         num_deleted = data['num_deleted']
@@ -635,7 +729,7 @@ class BaseCacheManageMiddlewareTest(object):
         path = "http://%s:%d/v1/queued_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         num_deleted = data['num_deleted']
@@ -677,7 +771,7 @@ log_file = %(log_file)s
         ids = {}
 
         # Add a bunch of images...
-        for x in xrange(4):
+        for x in range(4):
             ids[x] = self.add_image("Image%s" % str(x))
 
         # Queue the first image, verify no images still in cache after queueing
@@ -687,7 +781,7 @@ log_file = %(log_file)s
                                                      self.api_port, ids[0])
         http = httplib2.Http()
         response, content = http.request(path, 'PUT')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         self.verify_no_cached_images()
 
@@ -703,7 +797,7 @@ log_file = %(log_file)s
         path = "http://%s:%d/v1/cached_images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(response.status, 200)
+        self.assertEqual(200, response.status)
 
         data = jsonutils.loads(content)
         self.assertTrue('cached_images' in data)
