@@ -15,9 +15,9 @@
 
 import uuid
 
+from oslo.serialization import jsonutils
 import requests
 
-from glance.openstack.common import jsonutils
 from glance.tests import functional
 
 TENANT1 = str(uuid.uuid4())
@@ -88,6 +88,7 @@ class TestMetadefObjects(functional.FunctionalTest):
                         "type": "integer",
                         "title": "property1",
                         "description": "property1 description",
+                        "operators": ["<all-in>"],
                         "default": 100,
                         "minimum": 100,
                         "maximum": 30000369
@@ -139,6 +140,7 @@ class TestMetadefObjects(functional.FunctionalTest):
                     'type': 'integer',
                     "title": "property1",
                     'description': 'property1 description',
+                    'operators': ['<all-in>'],
                     'default': 100,
                     'minimum': 100,
                     'maximum': 30000369
@@ -159,7 +161,7 @@ class TestMetadefObjects(functional.FunctionalTest):
             "schema": "v2/schemas/metadefs/object"
         }
 
-        #Simple key values
+        # Simple key values
         checked_values = set([
             u'name',
             u'description',
@@ -167,7 +169,7 @@ class TestMetadefObjects(functional.FunctionalTest):
         for key, value in expected_metadata_object.items():
             if(key in checked_values):
                 self.assertEqual(metadata_object[key], value, key)
-        #Complex key values - properties
+        # Complex key values - properties
         for key, value in \
                 expected_metadata_object["properties"]['property2'].items():
             self.assertEqual(
@@ -201,6 +203,7 @@ class TestMetadefObjects(functional.FunctionalTest):
                         "type": "string",
                         "title": "property2",
                         "description": "p2 desc-UPDATED",
+                        'operators': ['<or>'],
                         "default": "value2-UPDATED",
                         "minLength": 5,
                         "maxLength": 150
@@ -223,6 +226,7 @@ class TestMetadefObjects(functional.FunctionalTest):
         self.assertEqual('500', updated_property1['default'])
         self.assertEqual(500, updated_property1['minimum'])
         self.assertEqual(1369, updated_property1['maximum'])
+        self.assertEqual(['<or>'], updated_property2['operators'])
         self.assertEqual('string', updated_property2['type'])
         self.assertEqual('p2 desc-UPDATED', updated_property2['description'])
         self.assertEqual('value2-UPDATED', updated_property2['default'])
@@ -244,6 +248,7 @@ class TestMetadefObjects(functional.FunctionalTest):
         self.assertEqual('500', updated_property1['default'])
         self.assertEqual(500, updated_property1['minimum'])
         self.assertEqual(1369, updated_property1['maximum'])
+        self.assertEqual(['<or>'], updated_property2['operators'])
         self.assertEqual('string', updated_property2['type'])
         self.assertEqual('p2 desc-UPDATED', updated_property2['description'])
         self.assertEqual('value2-UPDATED', updated_property2['default'])
