@@ -94,6 +94,22 @@ class TestImportTask(test_utils.BaseTestCase):
                 rm_mock.return_value = None
                 image_convert.execute(image, 'file:///test/path.raw')
 
+    def test_convert_revert_success(self):
+        image_convert = convert._Convert(self.task.task_id,
+                                         self.task_type,
+                                         self.img_repo)
+
+        self.task_repo.get.return_value = self.task
+        image_id = mock.sentinel.image_id
+        image = mock.MagicMock(image_id=image_id, virtual_size=None)
+        self.img_repo.get.return_value = image
+
+        with mock.patch.object(processutils, 'execute') as exc_mock:
+            exc_mock.return_value = ("", None)
+            with mock.patch.object(os, 'remove') as rmtree_mock:
+                rmtree_mock.return_value = None
+                image_convert.revert(image, 'file:///tmp/test')
+
     def test_import_flow_with_convert_and_introspect(self):
         self.config(engine_mode='serial',
                     group='taskflow_executor')
