@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from six.moves import xrange
+# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
+from six.moves import range
 
 from glance.api import policy
 from glance.common import exception
@@ -29,6 +30,7 @@ CONFIG_SECTIONS = [
     'spl_update_prop',
     'spl_update_only_prop',
     'spl_delete_prop',
+    'spl_delete_empty_prop',
     '^x_all_permitted.*',
     '^x_none_permitted.*',
     'x_none_read',
@@ -40,7 +42,9 @@ CONFIG_SECTIONS = [
 ]
 
 
-def create_context(policy, roles=[]):
+def create_context(policy, roles=None):
+    if roles is None:
+        roles = []
     return glance.context.RequestContext(roles=roles,
                                          policy_enforcer=policy)
 
@@ -194,7 +198,7 @@ class TestPropertyRulesWithRoles(base.IsolatedUnitTest):
         configuration file
         """
         self.rules_checker = property_utils.PropertyRules(self.policy)
-        self.assertEqual(property_utils.CONFIG.sections(), CONFIG_SECTIONS)
+        self.assertEqual(CONFIG_SECTIONS, property_utils.CONFIG.sections())
 
     def test_property_rules_loaded_in_order(self):
         """
@@ -202,7 +206,7 @@ class TestPropertyRulesWithRoles(base.IsolatedUnitTest):
         file
         """
         self.rules_checker = property_utils.PropertyRules(self.policy)
-        for i in xrange(len(property_utils.CONFIG.sections())):
+        for i in range(len(property_utils.CONFIG.sections())):
             self.assertEqual(property_utils.CONFIG.sections()[i],
                              self.rules_checker.rules[i][0].pattern)
 
