@@ -16,15 +16,14 @@
 #    under the License.
 import datetime
 
-import mox
-from oslo.config import cfg
+from oslo.serialization import jsonutils
+from oslo_config import cfg
 import routes
 import webob
 
 from glance.common import exception
 from glance.common import rpc
 from glance.common import wsgi
-from glance.openstack.common import jsonutils
 from glance.tests.unit import base
 from glance.tests import utils as test_utils
 
@@ -77,9 +76,6 @@ class TestRPCController(base.IsolatedUnitTest):
         self.controller = rpc.Controller()
         self.controller.register(self.res)
 
-        # Mock
-        self.mocker = mox.Mox()
-
     def test_register(self):
         res = FakeResource()
         controller = rpc.Controller()
@@ -131,7 +127,7 @@ class TestRPCController(base.IsolatedUnitTest):
         res = req.get_response(api)
         returned = jsonutils.loads(res.body)
         self.assertIsInstance(returned, list)
-        self.assertEqual(returned[0], 1)
+        self.assertEqual(1, returned[0])
 
     def test_request_exc(self):
         api = create_api()
@@ -159,27 +155,27 @@ class TestRPCController(base.IsolatedUnitTest):
         # Body is not a list, it should fail
         req.body = jsonutils.dumps({})
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 400)
+        self.assertEqual(400, res.status_int)
 
         # cmd is not dict, it should fail.
         req.body = jsonutils.dumps([None])
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 400)
+        self.assertEqual(400, res.status_int)
 
         # No command key, it should fail.
         req.body = jsonutils.dumps([{}])
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 400)
+        self.assertEqual(400, res.status_int)
 
         # kwargs not dict, it should fail.
         req.body = jsonutils.dumps([{"command": "test", "kwargs": 200}])
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 400)
+        self.assertEqual(400, res.status_int)
 
         # Command does not exist, it should fail.
         req.body = jsonutils.dumps([{"command": "test"}])
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 404)
+        self.assertEqual(404, res.status_int)
 
     def test_rpc_exception_propagation(self):
         api = create_api()
@@ -189,18 +185,18 @@ class TestRPCController(base.IsolatedUnitTest):
 
         req.body = jsonutils.dumps([{"command": "raise_value_error"}])
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 200)
+        self.assertEqual(200, res.status_int)
 
         returned = jsonutils.loads(res.body)[0]
-        self.assertEqual(returned['_error']['cls'], 'exceptions.ValueError')
+        self.assertEqual('exceptions.ValueError', returned['_error']['cls'])
 
         req.body = jsonutils.dumps([{"command": "raise_weird_error"}])
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 200)
+        self.assertEqual(200, res.status_int)
 
         returned = jsonutils.loads(res.body)[0]
-        self.assertEqual(returned['_error']['cls'],
-                         'glance.common.exception.RPCError')
+        self.assertEqual('glance.common.exception.RPCError',
+                         returned['_error']['cls'])
 
 
 class TestRPCClient(base.IsolatedUnitTest):
@@ -230,7 +226,7 @@ class TestRPCClient(base.IsolatedUnitTest):
                     {"command": "get_all_images"}]
 
         res = self.client.bulk_request(commands)
-        self.assertEqual(len(res), 2)
+        self.assertEqual(2, len(res))
         self.assertTrue(res[0])
         self.assertFalse(res[1])
 
@@ -239,7 +235,7 @@ class TestRPCClient(base.IsolatedUnitTest):
             self.client.raise_value_error()
             self.fail("Exception not raised")
         except ValueError as exc:
-            self.assertEqual(str(exc), "Yep, Just like that!")
+            self.assertEqual("Yep, Just like that!", str(exc))
 
     def test_rpc_exception(self):
         try:
@@ -250,7 +246,7 @@ class TestRPCClient(base.IsolatedUnitTest):
 
     def test_non_str_or_dict_response(self):
         rst = self.client.count_images(images=[1, 2, 3, 4])
-        self.assertEqual(rst, 4)
+        self.assertEqual(4, rst)
         self.assertIsInstance(rst, int)
 
 
@@ -260,7 +256,7 @@ class TestRPCJSONSerializer(test_utils.BaseTestCase):
         fixture = {"key": "value"}
         expected = '{"key": "value"}'
         actual = rpc.RPCJSONSerializer().to_json(fixture)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_to_json_with_date_format_value(self):
         fixture = {"date": datetime.datetime(1900, 3, 8, 2)}
@@ -284,12 +280,12 @@ class TestRPCJSONSerializer(test_utils.BaseTestCase):
         fixture = {"key": "value"}
         response = webob.Response()
         rpc.RPCJSONSerializer().default(response, fixture)
-        self.assertEqual(response.status_int, 200)
+        self.assertEqual(200, response.status_int)
         content_types = filter(lambda h: h[0] == 'Content-Type',
                                response.headerlist)
-        self.assertEqual(len(content_types), 1)
-        self.assertEqual(response.content_type, 'application/json')
-        self.assertEqual(response.body, '{"key": "value"}')
+        self.assertEqual(1, len(content_types))
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual('{"key": "value"}', response.body)
 
 
 class TestRPCJSONDeserializer(test_utils.BaseTestCase):
@@ -312,7 +308,7 @@ class TestRPCJSONDeserializer(test_utils.BaseTestCase):
         request = wsgi.Request.blank('/')
         request.method = 'POST'
         request.body = 'asdf'
-        self.assertTrue('Content-Length' in request.headers)
+        self.assertIn('Content-Length', request.headers)
         self.assertTrue(rpc.RPCJSONDeserializer().has_body(request))
 
     def test_no_body_no_content_length(self):
@@ -323,7 +319,7 @@ class TestRPCJSONDeserializer(test_utils.BaseTestCase):
         fixture = '{"key": "value"}'
         expected = {"key": "value"}
         actual = rpc.RPCJSONDeserializer().from_json(fixture)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_from_json_malformed(self):
         fixture = 'kjasdklfjsklajf'
@@ -334,7 +330,7 @@ class TestRPCJSONDeserializer(test_utils.BaseTestCase):
         request = wsgi.Request.blank('/')
         actual = rpc.RPCJSONDeserializer().default(request)
         expected = {}
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_default_with_body(self):
         request = wsgi.Request.blank('/')
@@ -342,14 +338,14 @@ class TestRPCJSONDeserializer(test_utils.BaseTestCase):
         request.body = '{"key": "value"}'
         actual = rpc.RPCJSONDeserializer().default(request)
         expected = {"body": {"key": "value"}}
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_has_body_has_transfer_encoding(self):
         request = wsgi.Request.blank('/')
         request.method = 'POST'
         request.body = 'fake_body'
-        request.headers['transfer-encoding'] = 0
-        self.assertTrue('transfer-encoding' in request.headers)
+        request.headers['transfer-encoding'] = ''
+        self.assertIn('transfer-encoding', request.headers)
         self.assertTrue(rpc.RPCJSONDeserializer().has_body(request))
 
     def test_to_json_with_date_format_value(self):
@@ -357,4 +353,4 @@ class TestRPCJSONDeserializer(test_utils.BaseTestCase):
                    '"_type": "datetime"}}')
         expected = {"date": datetime.datetime(1900, 3, 8, 2)}
         actual = rpc.RPCJSONDeserializer().from_json(fixture)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
