@@ -20,14 +20,15 @@ import os
 import time
 
 import fixtures
+from oslo_utils import units
+from oslotest import moxstubout
 import six
-from six.moves import xrange
-import stubout
+# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
+from six.moves import range
 
 from glance.common import exception
 from glance import image_cache
-from glance.openstack.common import units
-#NOTE(bcwaldon): This is imported to load the registry config options
+# NOTE(bcwaldon): This is imported to load the registry config options
 import glance.registry  # noqa
 from glance.tests import utils as test_utils
 from glance.tests.utils import skip_if_disabled
@@ -152,8 +153,8 @@ class ImageCacheTestCase(object):
             incomplete_file.close()
 
         mtime = os.path.getmtime(incomplete_file_path_1)
-        pastday = datetime.datetime.fromtimestamp(mtime) - \
-            datetime.timedelta(days=1)
+        pastday = (datetime.datetime.fromtimestamp(mtime) -
+                   datetime.timedelta(days=1))
         atime = int(time.mktime(pastday.timetuple()))
         mtime = atime
         os.utime(incomplete_file_path_1, (atime, mtime))
@@ -173,38 +174,47 @@ class ImageCacheTestCase(object):
         """
         self.assertEqual(0, self.cache.get_cache_size())
 
-        # Add a bunch of images to the cache. The max cache
-        # size for the cache is set to 5KB and each image is
-        # 1K. We add 10 images to the cache and then we'll
-        # prune it. We should see only 5 images left after
-        # pruning, and the images that are least recently accessed
-        # should be the ones pruned...
-        for x in xrange(10):
+        # Add a bunch of images to the cache. The max cache size for the cache
+        # is set to 5KB and each image is 1K. We use 11 images in this test.
+        # The first 10 are added to and retrieved from cache in the same order.
+        # Then, the 11th image is added to cache but not retrieved before we
+        # prune. We should see only 5 images left after pruning, and the
+        # images that are least recently accessed should be the ones pruned...
+        for x in range(10):
             FIXTURE_FILE = six.StringIO(FIXTURE_DATA)
-            self.assertTrue(self.cache.cache_image_file(x,
-                                                        FIXTURE_FILE))
+            self.assertTrue(self.cache.cache_image_file(x, FIXTURE_FILE))
 
         self.assertEqual(10 * units.Ki, self.cache.get_cache_size())
 
         # OK, hit the images that are now cached...
-        for x in xrange(10):
+        for x in range(10):
             buff = six.StringIO()
             with self.cache.open_for_read(x) as cache_file:
                 for chunk in cache_file:
                     buff.write(chunk)
 
+        # Add a new image to cache.
+        # This is specifically to test the bug: 1438564
+        FIXTURE_FILE = six.StringIO(FIXTURE_DATA)
+        self.assertTrue(self.cache.cache_image_file(99, FIXTURE_FILE))
+
         self.cache.prune()
 
         self.assertEqual(5 * units.Ki, self.cache.get_cache_size())
 
-        for x in xrange(0, 5):
+        # Ensure images 0, 1, 2, 3, 4 & 5 are not cached anymore
+        for x in range(0, 6):
             self.assertFalse(self.cache.is_cached(x),
                              "Image %s was cached!" % x)
 
-        for x in xrange(5, 10):
+        # Ensure images 6, 7, 8 and 9 are still cached
+        for x in range(6, 10):
             self.assertTrue(self.cache.is_cached(x),
                             "Image %s was not cached!" % x)
 
+        # Ensure the newly added image, 99, is still cached
+        self.assertTrue(self.cache.is_cached(99), "Image 99 was not cached!")
+
     @skip_if_disabled
     def test_prune_to_zero(self):
         """Test that an image_cache_max_size of 0 doesn't kill the pruner
@@ -264,11 +274,11 @@ class ImageCacheTestCase(object):
 
         self.cache.delete_cached_image(1)
 
-        for x in xrange(3):
+        for x in range(3):
             self.assertTrue(self.cache.queue_image(x))
 
-        self.assertEqual(self.cache.get_queued_images(),
-                         ['0', '1', '2'])
+        self.assertEqual(['0', '1', '2'],
+                         self.cache.get_queued_images())
 
     def test_open_for_write_good(self):
         """
@@ -326,7 +336,7 @@ class ImageCacheTestCase(object):
             checksum = None
             caching_iter = self.cache.get_caching_iter(image_id, checksum,
                                                        iter(data))
-            self.assertEqual(list(caching_iter), data)
+            self.assertEqual(data, list(caching_iter))
 
         image_id = '1'
         self.assertFalse(self.cache.is_cached(image_id))
@@ -377,7 +387,7 @@ class ImageCacheTestCase(object):
             checksum = None
             caching_iter = self.cache.get_caching_iter(image_id, checksum,
                                                        iter(data))
-            self.assertEqual(caching_iter.next(), 'a')
+            self.assertEqual('a', caching_iter.next())
 
         image_id = '1'
         self.assertFalse(self.cache.is_cached(image_id))
@@ -506,9 +516,9 @@ class TestImageCacheNoDep(test_utils.BaseTestCase):
         def init_driver(self2):
             self2.driver = self.driver
 
-        self.stubs = stubout.StubOutForTesting()
+        mox_fixture = self.useFixture(moxstubout.MoxStubout())
+        self.stubs = mox_fixture.stubs
         self.stubs.Set(image_cache.ImageCache, 'init_driver', init_driver)
-        self.addCleanup(self.stubs.UnsetAll)
 
     def test_get_caching_iter_when_write_fails(self):
 
@@ -532,7 +542,7 @@ class TestImageCacheNoDep(test_utils.BaseTestCase):
         data = ['a', 'b', 'c', 'Fail', 'd', 'e', 'f']
 
         caching_iter = cache.get_caching_iter('dummy_id', None, iter(data))
-        self.assertEqual(list(caching_iter), data)
+        self.assertEqual(data, list(caching_iter))
 
     def test_get_caching_iter_when_open_fails(self):
 
@@ -550,4 +560,4 @@ class TestImageCacheNoDep(test_utils.BaseTestCase):
         data = ['a', 'b', 'c', 'd', 'e', 'f']
 
         caching_iter = cache.get_caching_iter('dummy_id', None, iter(data))
-        self.assertEqual(list(caching_iter), data)
+        self.assertEqual(data, list(caching_iter))
