@@ -15,6 +15,9 @@
 
 import os
 
+# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
+from six.moves import range
+
 from glance.common import crypt
 from glance.common import utils
 from glance.tests import utils as test_utils
@@ -63,8 +66,8 @@ class UtilsTestCase(test_utils.BaseTestCase):
         self.assertNotIn('x-image-meta-snafu', headers)
         self.assertNotIn('x-image-meta-property-arch', headers)
 
-        self.assertEqual(headers.get('x-image-meta-foo'), 'bar')
-        self.assertEqual(headers.get('x-image-meta-bells'), 'whistles')
-        self.assertEqual(headers.get('x-image-meta-empty'), '')
-        self.assertEqual(headers.get('x-image-meta-property-distro'), '')
-        self.assertEqual(headers.get('x-image-meta-property-user'), 'nobody')
+        self.assertEqual('bar', headers.get('x-image-meta-foo'))
+        self.assertEqual('whistles', headers.get('x-image-meta-bells'))
+        self.assertEqual('', headers.get('x-image-meta-empty'))
+        self.assertEqual('', headers.get('x-image-meta-property-distro'))
+        self.assertEqual('nobody', headers.get('x-image-meta-property-user'))
