@@ -42,7 +42,7 @@ class OptsTestCase(utils.BaseTestCase):
         opt_list = None
         for ep in pkg_resources.iter_entry_points('oslo.config.opts'):
             if ep.name == namespace:
-                list_fn = ep.load()
+                list_fn = ep.load(require=False)
                 opt_list = list_fn()
                 break
 
@@ -61,21 +61,9 @@ class OptsTestCase(utils.BaseTestCase):
             'paste_deploy'
         ]
         expected_opt_names = [
-            'debug',
-            'verbose',
-            'log-config-append',
-            'log-format',
-            'log-date-format',
-            'log-file',
-            'log-dir',
-            'use-syslog',
-            'use-syslog-rfc-format',
-            'syslog-log-facility',
             'owner_is_tenant',
             'admin_role',
             'allow_anonymous_access',
-            'policy_file',
-            'policy_default_rule',
             'allow_additional_image_properties',
             'image_member_quota',
             'image_property_quota',
@@ -102,7 +90,6 @@ class OptsTestCase(utils.BaseTestCase):
             'bind_host',
             'bind_port',
             'workers',
-            'eventlet_hub',
             'max_header_line',
             'backlog',
             'tcp_keepidle',
@@ -131,8 +118,6 @@ class OptsTestCase(utils.BaseTestCase):
             'registry_client_insecure',
             'registry_client_timeout',
             'send_identity_headers',
-            'disable_process_locking',
-            'lock_path',
             'scrubber_datadir',
             'scrub_time',
             'cleanup_scrubber',
@@ -142,11 +127,15 @@ class OptsTestCase(utils.BaseTestCase):
             'disk_formats',
             'task_time_to_live',
             'task_executor',
-            'eventlet_executor_pool_size',
+            'work_dir',
             'store_type_preference',
             'flavor',
             'config_file',
+            'public_endpoint',
+            'digest_algorithm',
             'http_keepalive',
+            'disabled_notifications',
+            'client_socket_timeout'
         ]
 
         self._check_opt_groups(opt_list, expected_opt_groups)
@@ -161,21 +150,9 @@ class OptsTestCase(utils.BaseTestCase):
             'paste_deploy'
         ]
         expected_opt_names = [
-            'debug',
-            'verbose',
-            'log-config-append',
-            'log-format',
-            'log-date-format',
-            'log-file',
-            'log-dir',
-            'use-syslog',
-            'use-syslog-rfc-format',
-            'syslog-log-facility',
             'owner_is_tenant',
             'admin_role',
             'allow_anonymous_access',
-            'policy_file',
-            'policy_default_rule',
             'allow_additional_image_properties',
             'image_member_quota',
             'image_property_quota',
@@ -203,11 +180,12 @@ class OptsTestCase(utils.BaseTestCase):
             'cert_file',
             'key_file',
             'workers',
-            'eventlet_hub',
             'max_header_line',
             'flavor',
             'config_file',
+            'digest_algorithm',
             'http_keepalive',
+            'client_socket_timeout'
         ]
 
         self._check_opt_groups(opt_list, expected_opt_groups)
@@ -221,18 +199,6 @@ class OptsTestCase(utils.BaseTestCase):
             None
         ]
         expected_opt_names = [
-            'debug',
-            'verbose',
-            'log-config-append',
-            'log-format',
-            'log-date-format',
-            'log-file',
-            'log-dir',
-            'use-syslog',
-            'use-syslog-rfc-format',
-            'syslog-log-facility',
-            'policy_file',
-            'policy_default_rule',
             'allow_additional_image_properties',
             'image_member_quota',
             'image_property_quota',
@@ -252,8 +218,6 @@ class OptsTestCase(utils.BaseTestCase):
             'pydev_worker_debug_host',
             'pydev_worker_debug_port',
             'metadata_encryption_key',
-            'disable_process_locking',
-            'lock_path',
             'scrubber_datadir',
             'scrub_time',
             'cleanup_scrubber',
@@ -269,7 +233,8 @@ class OptsTestCase(utils.BaseTestCase):
             'auth_strategy',
             'auth_region',
             'registry_host',
-            'registry_port'
+            'registry_port',
+            'digest_algorithm',
         ]
 
         self._check_opt_groups(opt_list, expected_opt_groups)
@@ -283,18 +248,6 @@ class OptsTestCase(utils.BaseTestCase):
             None
         ]
         expected_opt_names = [
-            'debug',
-            'verbose',
-            'log-config-append',
-            'log-format',
-            'log-date-format',
-            'log-file',
-            'log-dir',
-            'use-syslog',
-            'use-syslog-rfc-format',
-            'syslog-log-facility',
-            'policy_file',
-            'policy_default_rule',
             'allow_additional_image_properties',
             'image_member_quota',
             'image_property_quota',
@@ -327,7 +280,8 @@ class OptsTestCase(utils.BaseTestCase):
             'admin_tenant_name',
             'auth_url',
             'auth_strategy',
-            'auth_region'
+            'auth_region',
+            'digest_algorithm',
         ]
 
         self._check_opt_groups(opt_list, expected_opt_groups)
@@ -341,17 +295,6 @@ class OptsTestCase(utils.BaseTestCase):
             None,
         ]
         expected_opt_names = [
-            'debug',
-            'verbose',
-            'log-config-append',
-            'log-format',
-            'log-date-format',
-            'log-file',
-            'log-dir',
-            'use-syslog',
-            'use-syslog-rfc-format',
-            'syslog-log-facility',
-            'db_enforce_mysql_charset'
         ]
 
         self._check_opt_groups(opt_list, expected_opt_groups)
